(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    431757,      11635]
NotebookOptionsPosition[    425884,      11462]
NotebookOutlinePosition[    426236,      11477]
CellTagsIndexPosition[    426193,      11474]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Propagation cones of kinetic gravity braiding", "Section",
 CellChangeTimes->{{3.8089988459872313`*^9, 3.808998854997134*^9}, {
  3.810810129838333*^9, 3.810810153736329*^9}, {3.8154771815448008`*^9, 
  3.8154771892266417`*^9}}],

Cell[TextData[{
 "We derive the propagation cones of kinetic gravity braiding discussed in \
Appendix D of ",
 ButtonBox["arXiv:2007.06006",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2007.06006"], None},
  ButtonNote->"https://arxiv.org/abs/2007.06006"],
 ".\n\nAuthors: Reggie Bernardo and Ian Vega"
}], "Text",
 CellChangeTimes->{{3.808998944961481*^9, 3.8089989573662977`*^9}, {
  3.8098423926000004`*^9, 3.809842465741768*^9}, {3.8108099476656437`*^9, 
  3.8108100602494926`*^9}, {3.810810094920124*^9, 3.810810114320568*^9}, {
  3.811136294202736*^9, 3.8111362949222593`*^9}, {3.8154771985368*^9, 
  3.815477233117404*^9}, {3.815477285664345*^9, 3.8154772946222525`*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Setup of xPert",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.7825182775292244`*^9, 3.7825182823093467`*^9}, {
   3.808998986131352*^9, 3.8089989869162517`*^9}, {3.810810188667959*^9, 
   3.8108101959623623`*^9}, {3.8108103938788066`*^9, 
   3.8108103978467393`*^9}, {3.810810463090153*^9, 3.8108104636839123`*^9}, 
   3.815477256022437*^9}],

Cell["Start xAct...", "Text",
 CellChangeTimes->{{3.7825182849962177`*^9, 3.7825183338597527`*^9}, {
  3.8154772811966677`*^9, 3.8154772831599483`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"<<", "xAct`xPert`"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "optional", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$PrePrint", "=", "ScreenDollarIndices"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Options", "[", "MakeRule", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "ContractMetric", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefManifold", "[", 
   RowBox[{"M", ",", "4", ",", 
    RowBox[{"{", 
     RowBox[{
     "b", ",", "c", ",", "d", ",", "e", ",", "i", ",", "j", ",", "l", ",", 
      "q", ",", "s"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefMetric", "[", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{"g", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "CD", ",", 
    RowBox[{"{", 
     RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
   "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7825183433574996`*^9, 3.782518374600165*^9}, {
   3.7825184372181983`*^9, 3.78251845390189*^9}, 3.7825184884561234`*^9, 
   3.78252514501201*^9, {3.815477260110684*^9, 3.8154772604443636`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788393573956`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.81547883936067*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788393704643`*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788394136715`*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839461625*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839466762*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788394706974`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788394775763`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788396466217`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.6\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.6", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839651935*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839655899*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.81547883966083*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788396638207`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839667813*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839672804*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839676839*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788396808248`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788396849403`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839688826*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", "manifold ", $CellContext`M,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788396937428`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentM", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentM, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788396979914`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788397018166`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788397077694`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839712756*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag\[Dagger][-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839717742*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CD", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788397217317`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788397267213`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788397317057`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839735697*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788397406816`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788397452497`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839749237*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839763232*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788397681866`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839806713*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.815478839918586*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788399467535`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788399516516`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788401292887`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788401433287`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9, 
   3.8108102088639755`*^9, 3.810810247925229*^9, 3.810811064742429*^9, 
   3.8108193274083433`*^9, 3.810819764153132*^9, 3.8108198460096335`*^9, 
   3.8108742538335714`*^9, 3.8108780580526123`*^9, 3.81089540177259*^9, 
   3.8108961027003975`*^9, 3.810962581503107*^9, 3.810967655947756*^9, 
   3.8109768654650106`*^9, 3.8109813022442455`*^9, 3.8109834054404597`*^9, 
   3.811071213163118*^9, 3.8111342635069156`*^9, 3.8111366115768337`*^9, 
   3.8111368231488047`*^9, 3.811137082026183*^9, 3.811137250213952*^9, 
   3.811139380622669*^9, 3.8119891500205765`*^9, 3.8119918888240957`*^9, 
   3.811992066117424*^9, 3.811992461637516*^9, 3.8154772394552956`*^9, 
   3.81547727717412*^9, 3.8154788401697364`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "We use the following code from the notebook ",
 StyleBox["ActionVariation_Metric_Fields.nb",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 " available in ",
 ButtonBox["https://github.com/xAct-contrib/examples",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://github.com/xAct-contrib/examples"], None},
  ButtonNote->"https://github.com/xAct-contrib/examples"],
 " to derive the field equations from the Lagrangian:"
}], "Text",
 CellChangeTimes->{{3.8089992354687047`*^9, 3.808999241166506*^9}, {
   3.810810329906356*^9, 3.8108103551527214`*^9}, 3.8154773663592157`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"setup", " ", "by", " ", "Cyril", " ", "Pitrou"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g_", "?", "MetricQ"}], "[", 
        RowBox[{
         RowBox[{"a_", "?", "UpIndexQ"}], ",", 
         RowBox[{"b_", "?", "UpIndexQ"}]}], "]"}], "|", 
       RowBox[{
        RowBox[{"g_", "?", "MetricQ"}], "[", 
        RowBox[{
         RowBox[{"a_", "?", "DownIndexQ"}], ",", 
         RowBox[{"b_", "?", "DownIndexQ"}]}], "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pertexpr", ",", "res", ",", "dgloc", ",", 
        RowBox[{"(*", 
         RowBox[{"dummyloc", ","}], "*)"}], "hp"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "We", " ", "define", " ", "the", " ", "metric", " ", "perturbation"}],
         ",", " ", 
        RowBox[{"if", " ", "not", " ", "defined", " ", "already"}]}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dgloc", "=", 
        RowBox[{"SymbolJoin", "[", 
         RowBox[{"\"\<\[Delta]\>\"", ",", "g"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"hp", "=", 
        RowBox[{"Head", "@", 
         RowBox[{"Perturbation", "[", 
          RowBox[{"g", "[", 
           RowBox[{
            RowBox[{"DownIndex", "@", "a"}], ",", 
            RowBox[{"DownIndex", "@", "b"}]}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"hp", "===", "Perturbation"}], ",", 
         RowBox[{"DefMetricPerturbation", "[", 
          RowBox[{"g", ",", "dgloc", ",", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<\[Epsilon]\>\"", ",", "g"}], "]"}]}], "]"}], ",", 
         RowBox[{"dgloc", "=", "hp"}]}], "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "We", " ", "perturb", " ", "wrt", " ", "to", " ", "the", " ", 
           "metric", " ", "and", " ", "if", " ", "it", " ", "is", " ", "the", 
           " ", "inverse", " ", "metric", " ", "we", " ", "put", " ", "a", 
           " ", "minus", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"pertexpr", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"DownIndexQ", "[", "a", "]"}], ",", "1", ",", 
                RowBox[{"-", "1"}]}], "]"}], ")"}], "*", 
             RowBox[{"ToCanonical", "@", 
              RowBox[{"ContractMetric", "@", 
               RowBox[{"ExpandPerturbation", "@", 
                RowBox[{"Perturbation", "[", "expr", "]"}]}]}]}]}], "/.", 
            RowBox[{
             RowBox[{"Perturbation", "[", "tens_", "]"}], "\[RuleDelayed]", 
             "0"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"We", " ", "then", " ", "use", " ", 
            RowBox[{"VarD", ".", " ", "It"}], " ", "happens", " ", "that", 
            " ", "some", " ", "trivial", " ", "Kronecker", " ", "appear", " ",
             "which", " ", "need", " ", "to", " ", "be", " ", "handle", " ", 
            "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dgloc", "[", 
                    RowBox[{
                    RowBox[{"LI", "[", "1", "]"}], ",", "a", ",", "b"}], 
                    "]"}], ",", 
                   RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}], "[", 
                 "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", "xTensorQ"}], ",", "covd_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "dummyloc", ",", "pertexpr", ",", "inds"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
           "We", " ", "use", " ", "a", " ", "dummy", " ", "name", " ", "for", 
            " ", "the", " ", "variation", " ", "of", " ", "the", " ", 
            "tensor"}], ",", " ", 
           RowBox[{
           "and", " ", "use", " ", "it", " ", "to", " ", "replace", " ", 
            "the", " ", "formal", " ", "first", " ", "order", " ", 
            "perturbation", " ", "the", " ", "tensor"}]}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "So", " ", "first", " ", "we", " ", "define", " ", "this", " ", 
           "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"dummyloc", "=", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"inds", "=", 
           RowBox[{"DummyIn", "/@", 
            RowBox[{"SlotsOfTensor", "[", "tensor", "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
            RowBox[{"DefTensor", "[", 
             RowBox[{
              RowBox[{"dummyloc", "@@", "inds"}], ",", 
              RowBox[{"First", "@", 
               RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
           RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "Then", " ", "we", " ", "perturb", " ", "the", " ", "action", " ", 
            "and", " ", "replace", " ", 
            RowBox[{"Perturbation", "[", 
             RowBox[{"Tensor", "[", "..", "]"}], "]"}], " ", "by", " ", 
            "this", " ", "dummy", " ", "tensor"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pertexpr", "=", 
           RowBox[{"(", 
            RowBox[{"ToCanonical", "@", 
             RowBox[{"ContractMetric", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ExpandPerturbation", "@", 
                 RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
                RowBox[{
                 RowBox[{"Perturbation", "[", 
                  RowBox[{
                   RowBox[{"tens_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                   "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
          ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"With", " ", "this", " ", "simple", " ", "head"}], ",", 
            " ", 
            RowBox[{"VarD", " ", "works", " ", 
             RowBox[{"correctly", ".", " ", "Again"}], " ", "we", " ", "need",
              " ", "to", " ", "handel", " ", "some", " ", "trivial", " ", 
             "Kronecker"}]}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dummyloc", "@@", "inds"}], ",", "covd"}], "]"}], 
                 "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "[", "inds___", "]"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"tensor", "[", "inds", "]"}], ",", 
      RowBox[{"CovDOfMetric", "@", 
       RowBox[{"First", "@", "$Metrics"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"tensor_", "?", "xTensorQ"}], "[", "inds___", "]"}], ",", 
      "covd_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "dummyloc", ",", "pertexpr"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"dummyloc", "=", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
            RowBox[{"DefTensor", "[", 
             RowBox[{
              RowBox[{"dummyloc", "[", "inds", "]"}], ",", 
              RowBox[{"First", "@", 
               RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
           RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"Perturbation", " ", "with", " ", "xPert"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pertexpr", "=", 
           RowBox[{"(", 
            RowBox[{"ToCanonical", "@", 
             RowBox[{"ContractMetric", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ExpandPerturbation", "@", 
                 RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
                RowBox[{
                 RowBox[{"Perturbation", "[", 
                  RowBox[{
                   RowBox[{"tens_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                   "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "VarD", " ", "and", " ", "removal", " ", "of", " ", 
            "KroneckerDelta"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dummyloc", "[", "inds", "]"}], ",", "covd"}], 
                  "]"}], "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"g_", "?", "MetricQ"}], "[", 
       RowBox[{"as__", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"UpIndexQ", "[", "#", "]"}], "||", 
            RowBox[{"DownIndexQ", "[", "#", "]"}]}], ")"}], "&"}], ")"}]}], 
       "]"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "sqrtg", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sqrtg", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"SignDetOfMetric", "[", "g", "]"}], 
          RowBox[{
           RowBox[{"Determinant", "[", "g", "]"}], "[", "]"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"ToCanonical", "[", 
        RowBox[{
         RowBox[{"PerturbAction", "[", 
          RowBox[{"expr", ",", 
           RowBox[{"g", "[", "as", "]"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"ReplaceDummies", "@", "expr"}], "*", 
          RowBox[{
           RowBox[{"PerturbAction", "[", 
            RowBox[{"sqrtg", ",", 
             RowBox[{"g", "[", "as", "]"}]}], "]"}], "/", "sqrtg"}]}]}], " ", 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}], ",", 
      RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", "tensor", ",", 
      RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"expr_", ",", 
       RowBox[{"tensor_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
            RowBox[{"Not", "[", 
             RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
         ")"}]}]}], "]"}], ":=", 
     RowBox[{"VarAction", "[", 
      RowBox[{"expr", ",", "tensor", ",", 
       RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"tensor_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
            RowBox[{"Not", "[", 
             RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
         ")"}]}], "[", "inds___", "]"}], ",", 
      RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"tensor", "[", "inds", "]"}], ",", 
      RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"expr_", ",", 
       RowBox[{
        RowBox[{"tensor_", "?", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
             RowBox[{"Not", "[", 
              RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
          ")"}]}], "[", "inds___", "]"}]}], "]"}], ":=", 
     RowBox[{"VarAction", "[", 
      RowBox[{"expr", ",", 
       RowBox[{"tensor", "[", "inds", "]"}], ",", 
       RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8154773771574707`*^9, 3.815477384847866*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["The ",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["propagation cones",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox[" of kinetic gravity braiding",
  FontColor->RGBColor[1, 0.5, 0.5]]
}], "Subsection",
 CellChangeTimes->{{3.808999081759553*^9, 3.808999086361288*^9}, {
  3.8108104207682953`*^9, 3.8108104397247486`*^9}, {3.8108104727354016`*^9, 
  3.8108105247365513`*^9}, {3.815477410096352*^9, 3.8154774193225217`*^9}}],

Cell["The kinetic gravity braiding (KGB) Lagrangian is given by...", "Text",
 CellChangeTimes->{{3.8089993041211004`*^9, 3.808999309865737*^9}, {
  3.810810526972247*^9, 3.8108105456236916`*^9}, {3.8108110461190376`*^9, 
  3.810811049362899*^9}, {3.815477441078407*^9, 3.815477450336839*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[Chi]", "[", "]"}], ",", "M"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "/@", 
   RowBox[{"{", 
    RowBox[{"V", ",", "G"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LK", "=", 
   RowBox[{"V", "[", 
    RowBox[{
     RowBox[{"\[Chi]", "[", "]"}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{
       RowBox[{"CD", "[", "j", "]"}], "[", 
       RowBox[{"\[Chi]", "[", "]"}], "]"}], 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "j"}], "]"}], "[", 
       RowBox[{"\[Chi]", "[", "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LG", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"G", "[", 
      RowBox[{
       RowBox[{"\[Chi]", "[", "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], 
        RowBox[{
         RowBox[{"CD", "[", "j", "]"}], "[", 
         RowBox[{"\[Chi]", "[", "]"}], "]"}], 
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "j"}], "]"}], "[", 
         RowBox[{"\[Chi]", "[", "]"}], "]"}]}]}], "]"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "i", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "i"}], "]"}], "[", 
      RowBox[{"\[Chi]", "[", "]"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LEH", "=", 
    RowBox[{"\[Kappa]", " ", 
     RowBox[{"RicciScalarCD", "[", "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<L\>\"", "\[Equal]", 
  RowBox[{"LK", "+", "LG", "+", "LEH"}]}]}], "Input",
 CellChangeTimes->{{3.808999175526078*^9, 3.808999193534913*^9}, {
   3.808999316637615*^9, 3.808999351739683*^9}, {3.8089994011096125`*^9, 
   3.808999408740201*^9}, {3.8089996605984926`*^9, 3.8089996975785723`*^9}, {
   3.8089997673659344`*^9, 3.8089997768874655`*^9}, {3.8089998528452425`*^9, 
   3.808999853062698*^9}, {3.809001162579857*^9, 3.8090011873735385`*^9}, {
   3.8108105549037495`*^9, 3.810810575568139*^9}, {3.810810725836607*^9, 
   3.8108107800427713`*^9}, {3.8108108182609596`*^9, 3.810810818659684*^9}, {
   3.8108110737060537`*^9, 3.8108110906397657`*^9}, 3.8108197781393433`*^9, {
   3.8108198233766956`*^9, 3.810819833343886*^9}, {3.811071859686487*^9, 
   3.811071860303463*^9}, {3.8110720326155677`*^9, 3.811072033451203*^9}, {
   3.8110731870795927`*^9, 3.811073188358612*^9}, {3.811136856516507*^9, 
   3.811136857250059*^9}, {3.8111370414627104`*^9, 3.811137042206128*^9}, {
   3.8154774556886883`*^9, 3.815477480691217*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Chi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Chi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.81081109598297*^9, 3.8108193361732616`*^9, 
  3.8108197804116216`*^9, 3.8108198534480386`*^9, 3.810874267286188*^9, 
  3.8108780684368153`*^9, 3.8108954172568455`*^9, 3.8108961137800756`*^9, 
  3.8109625845440416`*^9, 3.8109676629436073`*^9, 3.810976868149793*^9, 
  3.8109813103240395`*^9, 3.8109834082225065`*^9, 3.8111363542618895`*^9, 
  3.8111366923335876`*^9, 3.8111370003207455`*^9, 3.8111370989895973`*^9, 
  3.8111372535659475`*^9, 3.8111394754271374`*^9, 3.811991893413514*^9, 
  3.811992106598977*^9, 3.8119924762474747`*^9, 3.815477484190194*^9, 
  3.815478840342866*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "V", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`V, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.81081109598297*^9, 3.8108193361732616`*^9, 
  3.8108197804116216`*^9, 3.8108198534480386`*^9, 3.810874267286188*^9, 
  3.8108780684368153`*^9, 3.8108954172568455`*^9, 3.8108961137800756`*^9, 
  3.8109625845440416`*^9, 3.8109676629436073`*^9, 3.810976868149793*^9, 
  3.8109813103240395`*^9, 3.8109834082225065`*^9, 3.8111363542618895`*^9, 
  3.8111366923335876`*^9, 3.8111370003207455`*^9, 3.8111370989895973`*^9, 
  3.8111372535659475`*^9, 3.8111394754271374`*^9, 3.811991893413514*^9, 
  3.811992106598977*^9, 3.8119924762474747`*^9, 3.815477484190194*^9, 
  3.8154788403468094`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "G", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`G, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.81081109598297*^9, 3.8108193361732616`*^9, 
  3.8108197804116216`*^9, 3.8108198534480386`*^9, 3.810874267286188*^9, 
  3.8108780684368153`*^9, 3.8108954172568455`*^9, 3.8108961137800756`*^9, 
  3.8109625845440416`*^9, 3.8109676629436073`*^9, 3.810976868149793*^9, 
  3.8109813103240395`*^9, 3.8109834082225065`*^9, 3.8111363542618895`*^9, 
  3.8111366923335876`*^9, 3.8111370003207455`*^9, 3.8111370989895973`*^9, 
  3.8111372535659475`*^9, 3.8111394754271374`*^9, 3.811991893413514*^9, 
  3.811992106598977*^9, 3.8119924762474747`*^9, 3.815477484190194*^9, 
  3.815478840350855*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.81081109598297*^9, 3.8108193361732616`*^9, 
  3.8108197804116216`*^9, 3.8108198534480386`*^9, 3.810874267286188*^9, 
  3.8108780684368153`*^9, 3.8108954172568455`*^9, 3.8108961137800756`*^9, 
  3.8109625845440416`*^9, 3.8109676629436073`*^9, 3.810976868149793*^9, 
  3.8109813103240395`*^9, 3.8109834082225065`*^9, 3.8111363542618895`*^9, 
  3.8111366923335876`*^9, 3.8111370003207455`*^9, 3.8111370989895973`*^9, 
  3.8111372535659475`*^9, 3.8111394754271374`*^9, 3.811991893413514*^9, 
  3.811992106598977*^9, 3.8119924762474747`*^9, 3.815477484190194*^9, 
  3.8154788403549085`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "j"], "\[Chi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`j][
        $CellContext`\[Chi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "j"], "\[Chi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`j][
        $CellContext`\[Chi][]],
       Editable->False]}]}], "]"}], "-", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "j"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`j][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "j"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`j][
         $CellContext`\[Chi][]],
        Editable->False]}]}], "]"}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "i"], 
       SubscriptBox["\[Del]", "i"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`i][
      $CellContext`CD[-$CellContext`i][
       $CellContext`\[Chi][]]],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{{3.8089993937383313`*^9, 3.8089994103050203`*^9}, 
   3.808999508534257*^9, 3.808999615003456*^9, 3.808999728314355*^9, 
   3.8089997789778337`*^9, {3.8089998496118917`*^9, 3.8089998733075047`*^9}, 
   3.8090005203937173`*^9, 3.809001217303507*^9, 3.8090028558573074`*^9, 
   3.809049708592515*^9, 3.8090547326482267`*^9, 3.809060405581639*^9, 
   3.8090759317745075`*^9, 3.8090784180508814`*^9, 3.8090841953392825`*^9, 
   3.809086111125476*^9, 3.809088039737887*^9, 3.80914072670062*^9, 
   3.809146655526019*^9, 3.809148901725876*^9, 3.809157721763899*^9, 
   3.8091648268938923`*^9, 3.8091677635772157`*^9, 3.8091718035080295`*^9, 
   3.8093200835698724`*^9, 3.8093357607902007`*^9, 3.8093415252629533`*^9, 
   3.809347774308766*^9, 3.8095723046102295`*^9, 3.809591628926898*^9, 
   3.8095921603236074`*^9, 3.809592504473201*^9, 3.8095931635976486`*^9, 
   3.8095954008612375`*^9, 3.809598165850277*^9, 3.8096150250236917`*^9, 
   3.8097454212538233`*^9, 3.8097456310376635`*^9, 3.809750711651189*^9, 
   3.8097525507855196`*^9, 3.8097530725518503`*^9, 3.8097630971445985`*^9, 
   3.8097666128470044`*^9, 3.8097720529332037`*^9, 3.8097834330939503`*^9, 
   3.8097871230982385`*^9, 3.8097875260167446`*^9, 3.8098309938677616`*^9, 
   3.8098392920387754`*^9, 3.8098435166813974`*^9, 3.8098443352070065`*^9, 
   3.809863391825446*^9, 3.809867358034668*^9, {3.8108107945610633`*^9, 
   3.8108108194391003`*^9}, 3.8108110960101247`*^9, 3.81081933620033*^9, 
   3.8108197804424224`*^9, 3.8108198534751196`*^9, 3.8108742673135505`*^9, 
   3.810878068462716*^9, 3.810895417315506*^9, 3.8108961138003645`*^9, 
   3.810962584578751*^9, 3.810967662973505*^9, 3.810976868178724*^9, 
   3.810981310355276*^9, 3.8109834082537794`*^9, 3.811136354307125*^9, 
   3.811136692350994*^9, 3.811137000352071*^9, 3.8111370990191493`*^9, 
   3.811137253589673*^9, 3.8111394754578137`*^9, 3.8119918934419403`*^9, 
   3.8119921066194987`*^9, 3.8119924762804575`*^9, 3.815477484215943*^9, 
   3.8154788403627896`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preparation", "Subsubsection",
 CellChangeTimes->{{3.8108193874740314`*^9, 3.8108193989935727`*^9}, {
  3.815477573992197*^9, 3.815477603787935*^9}, {3.815478508345537*^9, 
  3.815478509682103*^9}}],

Cell["For aesthetics...", "Text",
 CellChangeTimes->{{3.810877745398488*^9, 3.8108777489323425`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefTensor", "[", 
    RowBox[{
     RowBox[{"X", "[", "]"}], ",", "M"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SimpVG", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{
        RowBox[{"\[Chi]", "[", "]"}], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         RowBox[{"Scalar", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"CD", "[", 
             RowBox[{"-", "b_"}], "]"}], "[", 
            RowBox[{"\[Chi]", "[", "]"}], "]"}], 
           RowBox[{
            RowBox[{"CD", "[", "b_", "]"}], "[", 
            RowBox[{"\[Chi]", "[", "]"}], "]"}]}], "]"}]}]}], "]"}], 
      "\[Rule]", 
      RowBox[{"V", "[", 
       RowBox[{
        RowBox[{"\[Chi]", "[", "]"}], ",", 
        RowBox[{"X", "[", "]"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"x_", ",", "y_"}], "]"}], "[", "V", "]"}], "[", 
       RowBox[{
        RowBox[{"\[Chi]", "[", "]"}], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         RowBox[{"Scalar", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"CD", "[", 
             RowBox[{"-", "b"}], "]"}], "[", 
            RowBox[{"\[Chi]", "[", "]"}], "]"}], 
           RowBox[{
            RowBox[{"CD", "[", "b", "]"}], "[", 
            RowBox[{"\[Chi]", "[", "]"}], "]"}]}], "]"}]}]}], "]"}], 
      "\[RuleDelayed]", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "[", "V", "]"}], "[", 
       RowBox[{
        RowBox[{"\[Chi]", "[", "]"}], ",", 
        RowBox[{"X", "[", "]"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"x_", ",", "y_"}], "]"}], "[", "G", "]"}], "[", 
       RowBox[{
        RowBox[{"\[Chi]", "[", "]"}], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         RowBox[{"Scalar", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"CD", "[", 
             RowBox[{"-", "b"}], "]"}], "[", 
            RowBox[{"\[Chi]", "[", "]"}], "]"}], 
           RowBox[{
            RowBox[{"CD", "[", "b", "]"}], "[", 
            RowBox[{"\[Chi]", "[", "]"}], "]"}]}], "]"}]}]}], "]"}], 
      "\[RuleDelayed]", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "[", "G", "]"}], "[", 
       RowBox[{
        RowBox[{"\[Chi]", "[", "]"}], ",", 
        RowBox[{"X", "[", "]"}]}], "]"}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.810877751704872*^9, 3.8108777786841965`*^9}, {
  3.810877820000817*^9, 3.8108778706540546`*^9}, {3.8108779306856833`*^9, 
  3.8108779910086637`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"X", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`X[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.810878073731224*^9, 3.8108954247435713`*^9, 
  3.8108961193825088`*^9, 3.810962584605299*^9, 3.8109676691870546`*^9, 
  3.8109768682058144`*^9, 3.8109813336121902`*^9, 3.810983408285021*^9, 
  3.8111363544008303`*^9, 3.811136695074532*^9, 3.8111370082471075`*^9, 
  3.8111371021361465`*^9, 3.8111372536174145`*^9, 3.8111394801705904`*^9, 
  3.8119918934851947`*^9, 3.8119921095278435`*^9, 3.8119924821771383`*^9, 
  3.8154776088424377`*^9, 3.8154788403867245`*^9}]
}, Open  ]],

Cell["\<\
The scalar field\[CloseCurlyQuote]s stress-energy tensor (SET) in the \
physical frame is...\
\>", "Text",
 CellChangeTimes->{{3.8089993968639727`*^9, 3.808999431352763*^9}, {
  3.8108111338125644`*^9, 3.8108111375378056`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"TK", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"SortCovDs", "[", 
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"LK", ",", 
         RowBox[{"g", "[", 
          RowBox[{"b", ",", "c"}], "]"}]}], "]"}], ",", "CD"}], "]"}]}], "//",
     "ToCanonical"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TG", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"SortCovDs", "[", 
       RowBox[{
        RowBox[{"VarAction", "[", 
         RowBox[{"LG", ",", 
          RowBox[{"g", "[", 
           RowBox[{"b", ",", "c"}], "]"}]}], "]"}], ",", "CD"}], "]"}]}], "//",
      "ToCanonical"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(T\), \(bc\)], \((K)\)]\)\>\"", 
   "\[Equal]", "TK"}], "/.", "SimpVG"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(T\), \(bc\)], \((G)\)]\)\>\"", 
   "\[Equal]", "TG"}], "/.", "SimpVG"}]}], "Input",
 CellChangeTimes->{{3.808999441292127*^9, 3.8089994628205423`*^9}, {
  3.8089999727674923`*^9, 3.8090001073654113`*^9}, {3.809745498792444*^9, 
  3.8097455582804823`*^9}, {3.8108777180811224`*^9, 3.8108777429080496`*^9}, {
  3.810878000305015*^9, 3.8108780052931824`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]g", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon]g, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.815477612823447*^9, 3.8154788404064903`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]g", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]g[
    xAct`xTensor`LI["order"], -$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.815477612823447*^9, 3.81547884040956*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(T\\), \\(bc\\)], \\((K)\
\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.808999457906684*^9, 3.808999467709461*^9}, 
   3.8089995158018513`*^9, 3.8089995618626404`*^9, {3.808999619741781*^9, 
   3.80899964102485*^9}, 3.8089997951984777`*^9, {3.8090000703614273`*^9, 
   3.809000108897411*^9}, 3.8090005235053544`*^9, 3.8090012222023726`*^9, 
   3.8090028567020493`*^9, 3.809049713841962*^9, 3.8090547335440145`*^9, 
   3.8090604065424905`*^9, 3.809075932638261*^9, 3.8090784189746685`*^9, 
   3.8090841963226495`*^9, 3.8090861122550163`*^9, 3.8090880407129145`*^9, 
   3.8091407277413373`*^9, 3.8091466568608694`*^9, 3.809148902654929*^9, 
   3.8091577225126605`*^9, 3.809164828117792*^9, 3.8091677649162607`*^9, 
   3.8091718044200115`*^9, 3.8093200844138365`*^9, 3.8093357616390395`*^9, 
   3.8093415262568016`*^9, 3.8093477756040373`*^9, 3.809572305438156*^9, 
   3.809591629911666*^9, 3.809592161225831*^9, 3.8095925053770895`*^9, 
   3.809593164752731*^9, 3.8095954017406816`*^9, 3.8095981667170973`*^9, 
   3.809615025790388*^9, 3.8097454221600065`*^9, 3.809745559296891*^9, 
   3.8097456339594154`*^9, 3.8097507126037674`*^9, 3.809752551681884*^9, 
   3.809753073465721*^9, 3.8097630981076994`*^9, 3.8097666136191497`*^9, 
   3.809772053808535*^9, 3.809783434066723*^9, 3.8097871239873867`*^9, 
   3.8097875266788197`*^9, 3.809830994577841*^9, 3.809839292652156*^9, 
   3.8098435172807937`*^9, 3.8098443358691225`*^9, 3.8098633925052767`*^9, 
   3.809867358665715*^9, 3.8108108454075537`*^9, 3.810811122887892*^9, 
   3.8108193400089316`*^9, 3.8108197879235926`*^9, 3.810819861194951*^9, 
   3.81087427536219*^9, 3.810878006462758*^9, 3.8108780774343762`*^9, 
   3.8108954257083263`*^9, 3.810896120179311*^9, 3.8109625853381624`*^9, 
   3.81096767005392*^9, 3.810976868841937*^9, 3.8109813520869684`*^9, 
   3.8109834088636045`*^9, 3.8111363553016977`*^9, 3.8111366977804704`*^9, 
   3.8111370126448135`*^9, 3.811137104838523*^9, 3.8111372542514925`*^9, 
   3.811139483195711*^9, 3.8119918941758204`*^9, 3.811992115842551*^9, 
   3.8119924831373644`*^9, 3.8154776134790277`*^9, 3.8154788410037127`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(T\\), \\(bc\\)], \\((G)\
\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], "\[Chi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "e"], 
       SubscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`d][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "e"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.808999457906684*^9, 3.808999467709461*^9}, 
   3.8089995158018513`*^9, 3.8089995618626404`*^9, {3.808999619741781*^9, 
   3.80899964102485*^9}, 3.8089997951984777`*^9, {3.8090000703614273`*^9, 
   3.809000108897411*^9}, 3.8090005235053544`*^9, 3.8090012222023726`*^9, 
   3.8090028567020493`*^9, 3.809049713841962*^9, 3.8090547335440145`*^9, 
   3.8090604065424905`*^9, 3.809075932638261*^9, 3.8090784189746685`*^9, 
   3.8090841963226495`*^9, 3.8090861122550163`*^9, 3.8090880407129145`*^9, 
   3.8091407277413373`*^9, 3.8091466568608694`*^9, 3.809148902654929*^9, 
   3.8091577225126605`*^9, 3.809164828117792*^9, 3.8091677649162607`*^9, 
   3.8091718044200115`*^9, 3.8093200844138365`*^9, 3.8093357616390395`*^9, 
   3.8093415262568016`*^9, 3.8093477756040373`*^9, 3.809572305438156*^9, 
   3.809591629911666*^9, 3.809592161225831*^9, 3.8095925053770895`*^9, 
   3.809593164752731*^9, 3.8095954017406816`*^9, 3.8095981667170973`*^9, 
   3.809615025790388*^9, 3.8097454221600065`*^9, 3.809745559296891*^9, 
   3.8097456339594154`*^9, 3.8097507126037674`*^9, 3.809752551681884*^9, 
   3.809753073465721*^9, 3.8097630981076994`*^9, 3.8097666136191497`*^9, 
   3.809772053808535*^9, 3.809783434066723*^9, 3.8097871239873867`*^9, 
   3.8097875266788197`*^9, 3.809830994577841*^9, 3.809839292652156*^9, 
   3.8098435172807937`*^9, 3.8098443358691225`*^9, 3.8098633925052767`*^9, 
   3.809867358665715*^9, 3.8108108454075537`*^9, 3.810811122887892*^9, 
   3.8108193400089316`*^9, 3.8108197879235926`*^9, 3.810819861194951*^9, 
   3.81087427536219*^9, 3.810878006462758*^9, 3.8108780774343762`*^9, 
   3.8108954257083263`*^9, 3.810896120179311*^9, 3.8109625853381624`*^9, 
   3.81096767005392*^9, 3.810976868841937*^9, 3.8109813520869684`*^9, 
   3.8109834088636045`*^9, 3.8111363553016977`*^9, 3.8111366977804704`*^9, 
   3.8111370126448135`*^9, 3.811137104838523*^9, 3.8111372542514925`*^9, 
   3.811139483195711*^9, 3.8119918941758204`*^9, 3.811992115842551*^9, 
   3.8119924831373644`*^9, 3.8154776134790277`*^9, 3.8154788410389123`*^9}]
}, Open  ]],

Cell["The Einstein equation is given by...", "Text",
 CellChangeTimes->{{3.8090002161012144`*^9, 3.8090002210997953`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"TM", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "}"}], "]"}], ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<T\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"VarAction", "[", 
         RowBox[{"LEH", ",", 
          RowBox[{"g", "[", 
           RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "//", "RicciToEinstein"}],
        "//", "ToCanonical"}], ")"}], "-", 
     FractionBox["TK", "2"], "-", 
     FractionBox["TG", "2"]}], "\[Equal]", 
    FractionBox[
     RowBox[{"TM", "[", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "]"}], "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"EE", "/.", "SimpVG"}]}], "Input",
 CellChangeTimes->{{3.8090002330548143`*^9, 3.809000288100606*^9}, {
  3.809000344969448*^9, 3.80900035935003*^9}, {3.809000410032897*^9, 
  3.8090004871306577`*^9}, {3.8097455683774195`*^9, 3.8097455919466085`*^9}, {
  3.8108109408662567`*^9, 3.810810947792565*^9}, {3.810878012933499*^9, 
  3.810878015312634*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"TM", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`TM[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8108780802029333`*^9, 3.810895425782834*^9, 
  3.81089612024513*^9, 3.810962585514931*^9, 3.8109676701688585`*^9, 
  3.8109768689089622`*^9, 3.810981374937831*^9, 3.810983408926093*^9, 
  3.811136355447111*^9, 3.8111367009613113`*^9, 3.811137014930738*^9, 
  3.8111371067653484`*^9, 3.8111372543685713`*^9, 3.811139487224575*^9, 
  3.811991894332414*^9, 3.8119921177191577`*^9, 3.8119924832960443`*^9, 
  3.815477616090473*^9, 3.8154788410652294`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"g", 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`g[-$CellContext`b, -$CellContext`c],
         Editable->False]}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[-$CellContext`d][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}]}], ")"}]}]}], "\[Equal]", 
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" ", " "},
           {"b", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`TM[-$CellContext`b, -$CellContext`c],
    Editable->False], "2"]}]], "Output",
 CellChangeTimes->{{3.8090004636574526`*^9, 3.8090004891761823`*^9}, 
   3.8090005350365105`*^9, 3.809001229000187*^9, 3.8090028568925056`*^9, 
   3.8090497199317613`*^9, 3.809054733826643*^9, 3.8090604067332954`*^9, 
   3.809075932863594*^9, 3.8090784193163967`*^9, 3.8090841965762515`*^9, 
   3.8090861127048125`*^9, 3.8090880409742155`*^9, 3.8091407286539936`*^9, 
   3.8091466573663497`*^9, 3.8091489028413954`*^9, 3.809157722709076*^9, 
   3.8091648284344425`*^9, 3.8091677652146883`*^9, 3.8091718046419344`*^9, 
   3.8093200846169434`*^9, 3.8093357618468943`*^9, 3.809341526696372*^9, 
   3.8093477758514643`*^9, 3.80957230562372*^9, 3.809591630197565*^9, 
   3.8095921614404907`*^9, 3.809592505562637*^9, 3.809593165016089*^9, 
   3.8095954019822416`*^9, 3.8095981669370327`*^9, 3.8096150260090895`*^9, 
   3.8097454223474655`*^9, {3.8097455765514507`*^9, 3.809745593728563*^9}, 
   3.809745637492113*^9, 3.8097507128749995`*^9, 3.8097525520060835`*^9, 
   3.809753073908574*^9, 3.809763098501851*^9, 3.8097666138188777`*^9, 
   3.8097720540259995`*^9, 3.8097834346351075`*^9, 3.809787124455844*^9, 
   3.8097875268954215`*^9, 3.8098309948861184`*^9, 3.809839292855951*^9, 
   3.809843517497403*^9, 3.8098443361725893`*^9, 3.8098633927213507`*^9, 
   3.8098673589414434`*^9, 3.8108109033306828`*^9, 3.810810948334997*^9, 
   3.8108111272943907`*^9, 3.810819343367649*^9, 3.8108197882710285`*^9, 
   3.8108198615562863`*^9, 3.810874275706582*^9, 3.810878015976365*^9, 
   3.81087808043407*^9, 3.810895425967484*^9, 3.810896120454417*^9, 
   3.8109625856778135`*^9, 3.8109676703837996`*^9, 3.8109768690908537`*^9, 
   3.810981375140871*^9, 3.8109834091135807`*^9, 3.8111363556487427`*^9, 
   3.811136701181573*^9, 3.8111370151693296`*^9, 3.8111371069941*^9, 
   3.8111372545589323`*^9, 3.8111394875396104`*^9, 3.811991894512712*^9, 
   3.811992117934946*^9, 3.8119924835012355`*^9, 3.8154776162113104`*^9, 
   3.8154788411767206`*^9}]
}, Open  ]],

Cell["The scalar field equation is given by...", "Text",
 CellChangeTimes->{{3.809000600461502*^9, 3.8090006073401012`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SFE", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"SortCovDs", "[", 
       RowBox[{
        RowBox[{"VarAction", "[", 
         RowBox[{
          RowBox[{"LK", "+", "LG", "+", "LEH"}], ",", 
          RowBox[{"\[Chi]", "[", "]"}]}], "]"}], ",", "CD"}], "]"}], "//", 
      "ToCanonical"}], ")"}], "\[Equal]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"SFE", "/.", "SimpVG"}]}], "Input",
 CellChangeTimes->{{3.809000608205785*^9, 3.8090006456795444`*^9}, {
  3.8090012400256944`*^9, 3.8090012410539446`*^9}, {3.809745446354581*^9, 
  3.8097454750657454`*^9}, {3.8108193478232994`*^9, 3.8108193496859903`*^9}, {
  3.810878025374635*^9, 3.810878043171011*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], 
        SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Chi][]]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.8090006466419687`*^9, 3.80900124285712*^9, 3.809002857596655*^9, 
   3.8090497238467855`*^9, 3.8090547347178564`*^9, 3.8090604075781417`*^9, 
   3.809075933634167*^9, 3.8090784203060837`*^9, 3.809084198129816*^9, 
   3.8090861134338655`*^9, 3.8090880416952887`*^9, 3.809140729342307*^9, 
   3.8091466584377117`*^9, 3.8091489035308022`*^9, 3.8091577233688574`*^9, 
   3.8091648293383293`*^9, 3.809167766247755*^9, 3.8091718053969145`*^9, 
   3.809320085289344*^9, 3.8093357626008444`*^9, 3.809341527501058*^9, 
   3.8093477765586104`*^9, 3.8095723062954383`*^9, 3.809591631211376*^9, 
   3.8095921621846385`*^9, 3.8095925069203157`*^9, 3.8095931658526516`*^9, 
   3.809595402701291*^9, 3.8095981677101316`*^9, 3.8096150266811604`*^9, 
   3.8097454230816975`*^9, {3.809745454544505*^9, 3.809745476301226*^9}, 
   3.8097456423375053`*^9, 3.8097507137660627`*^9, 3.809752552820507*^9, 
   3.809753074781193*^9, 3.809763099408345*^9, 3.8097666146436267`*^9, 
   3.809772054898158*^9, 3.80978343551204*^9, 3.809787125350216*^9, 
   3.809787527689106*^9, 3.809830996262435*^9, 3.809839293625589*^9, 
   3.8098435181841736`*^9, 3.809844336985299*^9, 3.8098633935799713`*^9, 
   3.8098673598660197`*^9, 3.8108109908093233`*^9, 3.810811160888543*^9, 
   3.81081935299333*^9, 3.810819789131074*^9, 3.810819862440686*^9, 
   3.810874276514806*^9, {3.810878027337878*^9, 3.8108780344747796`*^9}, 
   3.8108780850044208`*^9, 3.810895426825647*^9, 3.810896121294959*^9, 
   3.810962586457036*^9, 3.810967671392968*^9, 3.8109768698510666`*^9, 
   3.8109813826116724`*^9, 3.8109834098639383`*^9, 3.811136355891869*^9, 
   3.8111367039033437`*^9, 3.811137110079507*^9, 3.811137255313644*^9, 
   3.811139495636427*^9, 3.8119918954010296`*^9, 3.8119921208036413`*^9, 
   3.8119924843205657`*^9, 3.8154776216242695`*^9, 3.815478841940629*^9}]
}, Open  ]],

Cell[TextData[{
 "Defining the scalar perturbation ",
 Cell[BoxData[
  FormBox["\[Delta]\[Chi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in xPert, the metric and scalar perturbations are therefore..."
}], "Text",
 CellChangeTimes->{{3.811071645374196*^9, 3.8110716658203735`*^9}, {
  3.8110718472073402`*^9, 3.8110718490571775`*^9}, {3.8154776497991385`*^9, 
  3.815477649961506*^9}, {3.8154778985266953`*^9, 3.815477941568511*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefTensorPerturbation", "[", 
    RowBox[{
     RowBox[{"\[Delta]\[Chi]", "[", 
      RowBox[{"LI", "[", "order", "]"}], "]"}], ",", 
     RowBox[{"\[Chi]", "[", "]"}], ",", "M"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{
    RowBox[{"-", "a"}], ",", 
    RowBox[{"-", "b"}]}], "]"}], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Perturbed", "[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], ",", "1"}], "]"}], "//", 
    "ExpandPerturbation"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]", "[", "]"}], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Perturbed", "[", 
     RowBox[{
      RowBox[{"\[Chi]", "[", "]"}], ",", "1"}], "]"}], "//", 
    "ExpandPerturbation"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.811071676852662*^9, 3.8110717832139874`*^9}, {
  3.81113705284587*^9, 3.81113705593406*^9}, {3.815477948711121*^9, 
  3.815477949364987*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]\[Chi]", "[", 
    RowBox[{"LI", "[", "\<\"order\"\>", "]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]\[Chi][
    xAct`xTensor`LI["order"]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.811137114035158*^9, 3.811137255382883*^9, 
  3.8119918954545946`*^9, 3.811992123070982*^9, 3.8119924843881216`*^9, 
  3.815477950340433*^9, 3.8154788419715605`*^9}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"g", 
       StyleBox[GridBox[{
          {" ", " "},
          {"a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`g[-$CellContext`a, -$CellContext`b],
   Editable->False], "\[Equal]", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`a, -$CellContext`b],
    Editable->False], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]g",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon]g,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]g", 
         StyleBox[GridBox[{
            {"1", " ", " "},
            {" ", "a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Delta]g[
      xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{{3.811071701694727*^9, 3.811071730859975*^9}, {
   3.811071763058001*^9, 3.8110717838040247`*^9}, 3.8111363559410286`*^9, 
   3.8111371140572567`*^9, 3.811137255401716*^9, 3.81199189546974*^9, 
   3.811992123099658*^9, 3.8119924844086514`*^9, 3.815477950366269*^9, 
   3.8154788419858427`*^9}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox["\[Chi]",
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`\[Chi][],
   Editable->False], "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]g",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon]g,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]\[Chi]", 
         StyleBox[GridBox[{
            {"1"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Delta]\[Chi][
      xAct`xTensor`LI[1]],
     Editable->False]}], "+", 
   InterpretationBox[
    StyleBox["\[Chi]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Chi][],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{{3.811071701694727*^9, 3.811071730859975*^9}, {
   3.811071763058001*^9, 3.8110717838040247`*^9}, 3.8111363559410286`*^9, 
   3.8111371140572567`*^9, 3.811137255401716*^9, 3.81199189546974*^9, 
   3.811992123099658*^9, 3.8119924844086514`*^9, 3.815477950366269*^9, 
   3.815478841997215*^9}]
}, Open  ]],

Cell[TextData[{
 "The full linearized metric and scalar field equations (",
 StyleBox["in vacuum",
  FontSlant->"Italic"],
 ") are therefore..."
}], "Text",
 CellChangeTimes->{
  3.8108136712553186`*^9, {3.8108781170651855`*^9, 3.8108781177605386`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "aesthetics", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"\[Epsilon]", ",", "StandardForm"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"StyleBox", "[", 
     RowBox[{
      RowBox[{"ToString", "[", "$PerturbationParameter", "]"}], ",", 
      RowBox[{"FontColor", "\[Rule]", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0.0", ",", " ", "1.0", ",", " ", "0.0"}], "]"}]}]}], "]"}]}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"organizes", " ", "in", " ", "perturbation", " ", "order"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"org", "[", "expr_", "]"}], ":=", 
    RowBox[{"NoScalar", "@", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"ContractMetric", "[", "expr", "]"}], ",", 
       "$PerturbationParameter", ",", "ToCanonical"}], "]"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EE1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Perturbation", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"EE", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/.", 
          RowBox[{
           RowBox[{"Scalar", "[", "x_", "]"}], "\[RuleDelayed]", "x"}]}], ",",
          "1"}], "]"}], "//", "ExpandPerturbation"}], "//", "org"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SFE1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Perturbation", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"SFE", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/.", 
          RowBox[{
           RowBox[{"Scalar", "[", "x_", "]"}], "\[RuleDelayed]", "x"}]}], ",",
          "1"}], "]"}], "//", "ExpandPerturbation"}], "//", "org"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8108138249537287`*^9, 3.810813836229679*^9}, {
   3.815478032170978*^9, 3.815478044811132*^9}, 3.815478078651538*^9}],

Cell[TextData[{
 "For convenience, we also define here the scalar perturbation (",
 Cell[BoxData[
  FormBox["\[Delta]\[CurlyPhi]", TraditionalForm]]],
 "), the trace-reversed metric (",
 Cell[BoxData[
  FormBox[
   OverscriptBox["h", "_"], TraditionalForm]]],
 "), and the propagation eigenstate-metric (",
 Cell[BoxData[
  FormBox[
   OverscriptBox["h", "~"], TraditionalForm]]],
 ")..."
}], "Text",
 CellChangeTimes->{{3.8108143303945093`*^9, 3.81081434401667*^9}, {
  3.8108164530314784`*^9, 3.810816504124322*^9}, {3.8108167097598486`*^9, 
  3.810816752284851*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefTensor", "[", 
    RowBox[{
     RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], ",", "M"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"hbar", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "hbar", "]"}], "^=", 
   "\"\<\!\(\*OverscriptBox[\(h\), \(_\)]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TraceReverse", "=", 
    RowBox[{"IndexRule", "[", 
     RowBox[{
      RowBox[{"\[Delta]g", "[", 
       RowBox[{
        RowBox[{"LI", "[", "1", "]"}], ",", "b_", ",", "c_"}], "]"}], ",", 
      RowBox[{
       RowBox[{"hbar", "[", 
        RowBox[{"b", ",", "c"}], "]"}], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"hbar", "[", 
         RowBox[{
          RowBox[{"-", "j"}], ",", "j"}], "]"}], 
        RowBox[{"g", "[", 
         RowBox[{"b", ",", "c"}], "]"}]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"htilde", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "htilde", "]"}], "^=", 
   "\"\<\!\(\*OverscriptBox[\(h\), \(~\)]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.810814346016222*^9, 3.8108144230340223`*^9}, {
  3.8108144770210285`*^9, 3.8108145466025553`*^9}, {3.810816524503319*^9, 
  3.8108165676481214`*^9}, {3.810816761388041*^9, 3.8108167852237697`*^9}, {
  3.811992442516996*^9, 3.811992442980624*^9}, {3.8154781954990582`*^9, 
  3.81547819939098*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]\[CurlyPhi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8154788441491623`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"hbar", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`hbar[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.815478844153184*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"htilde", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`htilde[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.815478844157172*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "In this way, we obtain the GR cone for example (cone of the Einstein tensor \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["G", "ab"], "[", 
    SubscriptBox["h", "cd"], "]"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ")..."
}], "Text",
 CellChangeTimes->{{3.8108145549321566`*^9, 3.810814570816657*^9}, {
  3.810814704355775*^9, 3.8108147151978054`*^9}, {3.8154781246078863`*^9, 
  3.8154781757735343`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Commute1", "=", 
    RowBox[{"IndexRule", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "d_"}], "]"}], "[", 
       RowBox[{
        RowBox[{"CD", "[", 
         RowBox[{"-", "b_"}], "]"}], "[", 
        RowBox[{"hbar", "[", 
         RowBox[{
          RowBox[{"-", "c_"}], ",", "d_"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"CommuteCovDs", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "d"}], "]"}], "[", 
         RowBox[{
          RowBox[{"CD", "[", 
           RowBox[{"-", "b"}], "]"}], "[", 
          RowBox[{"hbar", "[", 
           RowBox[{
            RowBox[{"-", "c"}], ",", "d"}], "]"}], "]"}], "]"}], ",", "CD", 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "b"}], ",", 
          RowBox[{"-", "d"}]}], "}"}]}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"Z", "[", 
     RowBox[{"-", "b"}], "]"}], ",", "M"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ToGauge", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"IndexRule", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "c_"}], "]"}], "[", 
         RowBox[{"hbar", "[", 
          RowBox[{"c_", ",", "d_"}], "]"}], "]"}], ",", 
        RowBox[{"Z", "[", "d", "]"}]}], "]"}], ",", 
      RowBox[{"IndexRule", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "c_"}], "]"}], "[", 
         RowBox[{"hbar", "[", 
          RowBox[{"d_", ",", "c_"}], "]"}], "]"}], ",", 
        RowBox[{"Z", "[", "d", "]"}]}], "]"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]G\), \(bc\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Perturbation", "[", 
              RowBox[{
               RowBox[{"EinsteinCD", "[", 
                RowBox[{
                 RowBox[{"-", "b"}], ",", 
                 RowBox[{"-", "c"}]}], "]"}], ",", "1"}], "]"}], "//", 
             "ExpandPerturbation"}], "//", "ToCanonical"}], ")"}], "/.", 
          "TraceReverse"}], "//", "ContractMetric"}], "//", "ToCanonical"}], 
       ")"}], "/.", "Commute1"}], "/.", "ToGauge"}], "//", "ToCanonical"}], 
   ")"}]}]}], "Input",
 CellChangeTimes->{{3.8108144262943077`*^9, 3.8108144496328015`*^9}, {
  3.8108145773632913`*^9, 3.810814665939333*^9}, {3.8108147271211424`*^9, 
  3.8108147422781267`*^9}, {3.8108149659933796`*^9, 3.810814997047098*^9}, {
  3.810815188293233*^9, 3.8108153476784763`*^9}, {3.810815513686846*^9, 
  3.8108155756231103`*^9}, {3.810815624392254*^9, 3.81081569489769*^9}, {
  3.81081582438418*^9, 3.8108159564765997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Z", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Z[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8154788441809254`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]G\\), \\(bc\\)]\\)\"\>", 
  "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {" ", "d"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hbar[-$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "d"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`b, -$CellContext`d],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {" ", "d"},
            {"b", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hbar[-$CellContext`b, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "d"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {"d", "e"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hbar[$CellContext`d, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " "},
            {"d", "e"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`d, -$CellContext`e],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hbar[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {"d", "e"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hbar[$CellContext`d, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " ", " ", " "},
            {"b", "d", "c", "e"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RiemannCD[-$CellContext`b, -$CellContext`d, \
-$CellContext`c, -$CellContext`e],
     Editable->False]}], "+", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], GridBox[{
         {"Z", 
          StyleBox[GridBox[{
             {" "},
             {"c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`Z[-$CellContext`c]],
     Editable->False], "2"], "+", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], GridBox[{
         {"Z", 
          StyleBox[GridBox[{
             {" "},
             {"b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`Z[-$CellContext`b]],
     Editable->False], "2"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], GridBox[{
         {"Z", 
          StyleBox[GridBox[{
             {"d"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`Z[$CellContext`d]],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], GridBox[{
         {
          OverscriptBox["h", "_"], 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`hbar[-$CellContext`b, -$CellContext`c]]],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{{3.8108145730729465`*^9, 3.810814666794082*^9}, {
   3.810814735273286*^9, 3.8108147428853655`*^9}, {3.8108149668364353`*^9, 
   3.8108149976329393`*^9}, 3.81081557648005*^9, {3.81081562702133*^9, 
   3.8108156450882244`*^9}, {3.810815685129763*^9, 3.810815696718755*^9}, {
   3.810815942758917*^9, 3.8108159572279544`*^9}, 3.81081937339216*^9, 
   3.8108197921910334`*^9, 3.810819865811122*^9, 3.810874279493931*^9, 
   3.8108781569599333`*^9, 3.810895429757888*^9, 3.8108961240249014`*^9, 
   3.8109625892893076`*^9, 3.810967674368797*^9, 3.810976872492597*^9, 
   3.810981416574835*^9, 3.810983412395672*^9, 3.811136357382665*^9, 
   3.811137128431136*^9, 3.811137258148714*^9, 3.8119918982794824`*^9, 
   3.811992136889874*^9, 3.811992487498003*^9, {3.815478184161031*^9, 
   3.8154782041077485`*^9}, 3.8154788443908587`*^9}]
}, Open  ]],

Cell[TextData[{
 "The propagation cone of the tensor mode is defined by ",
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[Del]", "d"], 
     SuperscriptBox["\[Del]", "d"], GridBox[{
       {
        OverscriptBox["h", "_"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"b", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`d][
    $CellContext`CD[$CellContext`d][
     $CellContext`hbar[-$CellContext`b, -$CellContext`c]]],
   Editable->False]],
  CellChangeTimes->{{3.8108145730729465`*^9, 3.810814666794082*^9}, {
    3.810814735273286*^9, 3.8108147428853655`*^9}, {3.8108149668364353`*^9, 
    3.8108149976329393`*^9}, 3.81081557648005*^9, {3.81081562702133*^9, 
    3.8108156450882244`*^9}, {3.810815685129763*^9, 3.810815696718755*^9}, {
    3.810815942758917*^9, 3.8108159572279544`*^9}, 3.81081937339216*^9, 
    3.8108197921910334`*^9, 3.810819865811122*^9, 3.810874279493931*^9, 
    3.8108781569599333`*^9, 3.810895429757888*^9, 3.8108961240249014`*^9, 
    3.8109625892893076`*^9, 3.810967674368797*^9, 3.810976872492597*^9, 
    3.810981416574835*^9, 3.810983412395672*^9, 3.811136357382665*^9, 
    3.811137128431136*^9, 3.811137258148714*^9, 3.8119918982794824`*^9, 
    3.811992136889874*^9, 3.811992487498003*^9, {3.815478184161031*^9, 
    3.8154782041077485`*^9}}],
 " as expected in GR.\n\nLater, for gauging away in terms of the more general \
",
 Cell[BoxData[
  FormBox[
   OverscriptBox["h", "~"], TraditionalForm]]],
 " basis and organizing expressions, we use..."
}], "Text",
 CellChangeTimes->{{3.8108157455377274`*^9, 3.8108158020606585`*^9}, {
  3.810877601870903*^9, 3.81087761991711*^9}, {3.810898075125801*^9, 
  3.8108980990318723`*^9}, {3.815478224774783*^9, 3.815478226260754*^9}, {
  3.8154782623538947`*^9, 3.815478374053912*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ToGaugehTilde", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"IndexRule", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "c_"}], "]"}], "[", 
         RowBox[{"htilde", "[", 
          RowBox[{"c_", ",", "d_"}], "]"}], "]"}], ",", 
        RowBox[{"Z", "[", "d", "]"}]}], "]"}], ",", 
      RowBox[{"IndexRule", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "c_"}], "]"}], "[", 
         RowBox[{"htilde", "[", 
          RowBox[{"d_", ",", "c_"}], "]"}], "]"}], ",", 
        RowBox[{"Z", "[", "d", "]"}]}], "]"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"for", " ", "organizing", " ", "terms"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CollectPert", "[", "expr_", "]"}], ":=", 
   RowBox[{"Collect", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hbar", "[", 
        RowBox[{"_", ",", "_"}], "]"}], ",", 
       RowBox[{
        RowBox[{"CD", "[", "_", "]"}], "[", 
        RowBox[{"hbar", "[", 
         RowBox[{"_", ",", "_"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"CD", "[", 
         RowBox[{"-", "b_"}], "]"}], "[", 
        RowBox[{
         RowBox[{"CD", "[", "b_", "]"}], "[", 
         RowBox[{"hbar", "[", 
          RowBox[{"_", ",", "_"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"htilde", "[", 
        RowBox[{"_", ",", "_"}], "]"}], ",", 
       RowBox[{
        RowBox[{"CD", "[", "_", "]"}], "[", 
        RowBox[{"htilde", "[", 
         RowBox[{"_", ",", "_"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"CD", "[", 
         RowBox[{"-", "b_"}], "]"}], "[", 
        RowBox[{
         RowBox[{"CD", "[", "b_", "]"}], "[", 
         RowBox[{"htilde", "[", 
          RowBox[{"_", ",", "_"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], ",", 
       RowBox[{
        RowBox[{"CD", "[", "_", "]"}], "[", 
        RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"CD", "[", 
         RowBox[{"-", "b_"}], "]"}], "[", 
        RowBox[{
         RowBox[{"CD", "[", "b_", "]"}], "[", 
         RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], "]"}], "]"}]}], "}"}], 
     ",", "ToCanonical"}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "collecting", " ", "perturbations", " ", "with", " ", "second", " ", 
    "derivatives"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get2ndDerivatives", "[", "expr_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"expr", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"CD", "[", 
             RowBox[{"-", "i_"}], "]"}], "[", 
            RowBox[{
             RowBox[{"CD", "[", "j_", "]"}], "[", 
             RowBox[{"hbar", "[", 
              RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "]"}], 
           "\[RuleDelayed]", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{
             RowBox[{"CD", "[", 
              RowBox[{"-", "i"}], "]"}], "[", 
             RowBox[{
              RowBox[{"CD", "[", "j", "]"}], "[", 
              RowBox[{"hbar", "[", 
               RowBox[{"x", ",", "y"}], "]"}], "]"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"CD", "[", 
             RowBox[{"-", "i_"}], "]"}], "[", 
            RowBox[{
             RowBox[{"CD", "[", "j_", "]"}], "[", 
             RowBox[{"htilde", "[", 
              RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "]"}], 
           "\[RuleDelayed]", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{
             RowBox[{"CD", "[", 
              RowBox[{"-", "i"}], "]"}], "[", 
             RowBox[{
              RowBox[{"CD", "[", "j", "]"}], "[", 
              RowBox[{"htilde", "[", 
               RowBox[{"x", ",", "y"}], "]"}], "]"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"CD", "[", 
             RowBox[{"-", "i_"}], "]"}], "[", 
            RowBox[{
             RowBox[{"CD", "[", "j_", "]"}], "[", 
             RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], "]"}], "]"}], 
           "\[RuleDelayed]", 
           RowBox[{"\[Eta]", " ", 
            RowBox[{
             RowBox[{"CD", "[", 
              RowBox[{"-", "i"}], "]"}], "[", 
             RowBox[{
              RowBox[{"CD", "[", "j", "]"}], "[", 
              RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], "]"}], "]"}]}]}]}], 
         "}"}]}], ",", "\[Eta]"}], "]"}], "//", "ToCanonical"}], ")"}], "+", 
   "\"\<O(\[Del]\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"h\",
FontSlant->\"Italic\"], \"~\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\[Del]\[Delta]\[CurlyPhi],\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"h\",
FontSlant->\"Italic\"], \"~\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\[Delta]\[CurlyPhi])\>\""}]}]}], "Input",
 CellChangeTimes->{{3.8108776385447073`*^9, 3.810877662210417*^9}, {
  3.810898080992354*^9, 3.810898107225184*^9}, {3.81089816432186*^9, 
  3.81089816825598*^9}, {3.8109814457570252`*^9, 3.8109816156545534`*^9}, {
  3.8109822518390846`*^9, 3.810982339022976*^9}}],

Cell[TextData[{
 "In GR, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["h", "~"], "=", 
    OverscriptBox["h", "_"]}], TraditionalForm]]],
 ", so there\[CloseCurlyQuote]s no need for the above definitions, but we \
have to prepare for scalar-tensor theory."
}], "Text",
 CellChangeTimes->{{3.8108776664044576`*^9, 3.8108776799721003`*^9}, {
  3.810981646804863*^9, 3.8109816773297687`*^9}, {3.8111371810786905`*^9, 
  3.8111371928460484`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Linearized field equations in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["h", "~"], "ab"], ",", "\[Psi]"}], ")"}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 ": The propagation cones of KGB"
}], "Subsubsection",
 CellChangeTimes->{{3.8109653311967926`*^9, 3.8109653400379124`*^9}, {
  3.8109654729841795`*^9, 3.8109654976320996`*^9}, {3.8154784042155743`*^9, 
  3.8154784191169443`*^9}}],

Cell["\<\
In this section, we perform the diagonalization of the KGB modes.

The field equations are of course given already by...\
\>", "Text",
 CellChangeTimes->{{3.8109654381339717`*^9, 3.8109654603011017`*^9}, {
  3.810965828760237*^9, 3.810965862018285*^9}, {3.815478439049045*^9, 
  3.8154784414040003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EE", "/.", "SimpVG"}], "\[IndentingNewLine]", 
 RowBox[{"SFE", "/.", "SimpVG"}]}], "Input",
 CellChangeTimes->{{3.810965864155997*^9, 3.8109658655906286`*^9}, {
  3.8109659089786015`*^9, 3.8109659174223027`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"g", 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`g[-$CellContext`b, -$CellContext`c],
         Editable->False]}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[-$CellContext`d][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}]}], ")"}]}]}], "\[Equal]", 
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" ", " "},
           {"b", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`TM[-$CellContext`b, -$CellContext`c],
    Editable->False], "2"]}]], "Output",
 CellChangeTimes->{3.81096586613243*^9, 3.8109659180820665`*^9, 
  3.8109676790175123`*^9, 3.8109768899355125`*^9, 3.8109829597371817`*^9, 
  3.810983426728026*^9, 3.8111363659400797`*^9, 3.811137274655554*^9, 
  3.811991907969221*^9, 3.811992591444503*^9, 3.8154784460134926`*^9, 
  3.8154788445077567`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], 
        SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Chi][]]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.81096586613243*^9, 3.8109659180820665`*^9, 
  3.8109676790175123`*^9, 3.8109768899355125`*^9, 3.8109829597371817`*^9, 
  3.810983426728026*^9, 3.8111363659400797`*^9, 3.811137274655554*^9, 
  3.811991907969221*^9, 3.811992591444503*^9, 3.8154784460134926`*^9, 
  3.815478844552848*^9}]
}, Open  ]],

Cell[TextData[{
 "The linearized field equations for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["h", "_"], "bc"], ",", 
     OverscriptBox["h", "_"], ",", "\[Delta]\[CurlyPhi]"}], ")"}], 
   TraditionalForm]]],
 " are given by..."
}], "Text",
 CellChangeTimes->{{3.8109659488916883`*^9, 3.810965966877657*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"linearized", " ", "field", " ", "equations"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"EE1LHdsk", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"EE1", "/.", 
                RowBox[{"IndexRule", "[", 
                 RowBox[{
                  RowBox[{"\[Delta]\[Chi]", "[", 
                   RowBox[{"LI", "[", "1", "]"}], "]"}], ",", 
                  RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}]}], "]"}]}], "/.", 
               "TraceReverse"}], "//", "EinsteinToRicci"}], "//", 
             "ContractMetric"}], "//", "ToCanonical"}], ")"}], "/.", 
          "Commute1"}], "//", "ToCanonical"}], "//", "CollectPert"}], ")"}], "/.",
       "SimpVG"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EE1TraceLHdsk", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"EE1LHdsk", " ", 
           RowBox[{"g", "[", 
            RowBox[{"b", ",", "c"}], "]"}]}], "//", "ToCanonical"}], "//", 
         "ContractMetric"}], "//", "CollectPert"}], ")"}], "/.", "SimpVG"}]}],
     ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SFE1LHdsk", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"SFE1", "/.", 
               RowBox[{"IndexRule", "[", 
                RowBox[{
                 RowBox[{"\[Delta]\[Chi]", "[", 
                  RowBox[{"LI", "[", "1", "]"}], "]"}], ",", 
                 RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}]}], "]"}]}], "/.", 
              "TraceReverse"}], "//", "ContractMetric"}], "//", 
            "ToCanonical"}], ")"}], "/.", "Commute1"}], "//", "ToCanonical"}],
         "//", "CollectPert"}], ")"}], "/.", "SimpVG"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"EE1LHdsk", "//", "Get2ndDerivatives"}], "\[IndentingNewLine]", 
   RowBox[{"EE1TraceLHdsk", "//", "Get2ndDerivatives"}], 
   "\[IndentingNewLine]", 
   RowBox[{"SFE1LHdsk", "//", "Get2ndDerivatives"}]}]}]], "Input",
 CellChangeTimes->{{3.810965976537018*^9, 3.810966013227454*^9}, {
  3.8109664478096223`*^9, 3.8109664828432384`*^9}, {3.8109829664877872`*^9, 
  3.8109829907314105`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Delta]\[CurlyPhi])\"\>", "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SubscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {" ", "d"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[-$CellContext`d][
      $CellContext`hbar[-$CellContext`c, $CellContext`d]]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {" ", "d"},
            {"b", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`d][
      $CellContext`hbar[-$CellContext`b, $CellContext`d]]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`hbar[-$CellContext`b, -$CellContext`c]]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"b", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`b, -$CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "e"], 
      SubscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {"d", "e"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`e][
     $CellContext`CD[-$CellContext`d][
      $CellContext`hbar[$CellContext`d, $CellContext`e]]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`d][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SubscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`d][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"b", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`b, -$CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`d][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "e"], 
      SubscriptBox["\[Del]", "d"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`e][
     $CellContext`CD[-$CellContext`d][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "e"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`e][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.8109829937479267`*^9, 3.8109830032505546`*^9}, 
   3.810983432433001*^9, 3.8111363695470047`*^9, 3.811137281497045*^9, 
   3.811991913385684*^9, 3.8119925986163006`*^9, 3.8154784635263777`*^9, 
   3.8154788504792542`*^9}],

Cell[BoxData[
 RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Delta]\[CurlyPhi])\"\>", "-", 
  RowBox[{
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {"b", "c"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`hbar[$CellContext`b, $CellContext`c]]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SuperscriptBox["\[Del]", "c"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {"b", " "},
            {" ", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[$CellContext`c][
      $CellContext`hbar[$CellContext`b, -$CellContext`b]]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SuperscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.8109829937479267`*^9, 3.8109830032505546`*^9}, 
   3.810983432433001*^9, 3.8111363695470047`*^9, 3.811137281497045*^9, 
   3.811991913385684*^9, 3.8119925986163006`*^9, 3.8154784635263777`*^9, 
   3.8154788505091505`*^9}],

Cell[BoxData[
 RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Delta]\[CurlyPhi])\"\>", "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {" ", "d"},
            {"b", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`d][
      $CellContext`hbar[-$CellContext`b, $CellContext`d]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`hbar[-$CellContext`b, -$CellContext`c]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "_"], 
         StyleBox[GridBox[{
            {"c", " "},
            {" ", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`hbar[$CellContext`c, -$CellContext`c]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SuperscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.8109829937479267`*^9, 3.8109830032505546`*^9}, 
   3.810983432433001*^9, 3.8111363695470047`*^9, 3.811137281497045*^9, 
   3.811991913385684*^9, 3.8119925986163006`*^9, 3.8154784635263777`*^9, 
   3.8154788506040707`*^9}]
}, Open  ]],

Cell[TextData[{
 "We diagonalize this by going to the basis ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["h", "~"], "bc"], ",", "\[Delta]\[CurlyPhi]"}], ")"}], 
   TraditionalForm]]],
 " defined by..."
}], "Text",
 CellChangeTimes->{{3.810966033914288*^9, 3.810966055399983*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hTildeLHdsk", "=", 
    RowBox[{"IndexRule", "[", 
     RowBox[{
      RowBox[{"hbar", "[", 
       RowBox[{"b_", ",", "c_"}], "]"}], ",", 
      RowBox[{
       RowBox[{"htilde", "[", 
        RowBox[{"b", ",", "c"}], "]"}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"0", ",", "1"}], "]"}], "[", "G", "]"}], "[", 
          RowBox[{
           RowBox[{"\[Chi]", "[", "]"}], ",", 
           RowBox[{"X", "[", "]"}]}], "]"}], "\[Kappa]"], 
        RowBox[{
         RowBox[{"CD", "[", "b", "]"}], "[", 
         RowBox[{"\[Chi]", "[", "]"}], "]"}], 
        RowBox[{
         RowBox[{"CD", "[", "c", "]"}], "[", 
         RowBox[{"\[Chi]", "[", "]"}], "]"}], 
        RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE1LHdskhTilde", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"EE1LHdsk", "/.", "hTildeLHdsk"}], "//", "ToCanonical"}], "//", 
     "ContractMetric"}], "//", "CollectPert"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE1TraceLHdskhTilde", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"EE1TraceLHdsk", "/.", "hTildeLHdsk"}], "//", "ToCanonical"}], "//",
      "ContractMetric"}], "//", "CollectPert"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFE1LHdskhTilde", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"SFE1LHdsk", "/.", "hTildeLHdsk"}], "//", "ToCanonical"}], "//",
       "ContractMetric"}], "//", "CollectPert"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"EE1LHdskhTilde", "//", "Get2ndDerivatives"}], "\[IndentingNewLine]", 
 RowBox[{"EE1TraceLHdskhTilde", "//", 
  "Get2ndDerivatives"}], "\[IndentingNewLine]", 
 RowBox[{"SFE1LHdskhTilde", "//", "Get2ndDerivatives"}]}], "Input",
 CellChangeTimes->{{3.810966061888013*^9, 3.8109661485965967`*^9}, {
   3.810966515915756*^9, 3.8109665919183664`*^9}, {3.810966695080407*^9, 
   3.810966735629593*^9}, 3.810966896660903*^9, {3.8109830116751122`*^9, 
   3.810983032103284*^9}, {3.815478474317817*^9, 3.8154784788609753`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Delta]\[CurlyPhi])\"\>", "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SubscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {" ", "d"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[-$CellContext`d][
      $CellContext`htilde[-$CellContext`c, $CellContext`d]]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {" ", "d"},
            {"b", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`d][
      $CellContext`htilde[-$CellContext`b, $CellContext`d]]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`htilde[-$CellContext`b, -$CellContext`c]]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"b", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`b, -$CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "e"], 
      SubscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {"d", "e"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`e][
     $CellContext`CD[-$CellContext`d][
      $CellContext`htilde[$CellContext`d, $CellContext`e]]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{3.810983041700263*^9, 3.810983441201518*^9, 
  3.8111363696789293`*^9, 3.8111372920127916`*^9, 3.8119919163379273`*^9, 
  3.811992609007209*^9, 3.8154784945538216`*^9, 3.8154788570492277`*^9}],

Cell[BoxData[
 RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Delta]\[CurlyPhi])\"\>", "-", 
  RowBox[{
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {"b", "c"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`htilde[$CellContext`b, $CellContext`c]]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SuperscriptBox["\[Del]", "c"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {"b", " "},
            {" ", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[$CellContext`c][
      $CellContext`htilde[$CellContext`b, -$CellContext`b]]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{3.810983041700263*^9, 3.810983441201518*^9, 
  3.8111363696789293`*^9, 3.8111372920127916`*^9, 3.8119919163379273`*^9, 
  3.811992609007209*^9, 3.8154784945538216`*^9, 3.815478857076247*^9}],

Cell[BoxData[
 RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"~\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\[Delta]\[CurlyPhi])\"\>", "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {" ", "d"},
            {"b", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`d][
      $CellContext`htilde[-$CellContext`b, $CellContext`d]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`htilde[-$CellContext`b, -$CellContext`c]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], GridBox[{
        {
         OverscriptBox["h", "~"], 
         StyleBox[GridBox[{
            {"c", " "},
            {" ", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`htilde[$CellContext`c, -$CellContext`c]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Chi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Chi][],
        Editable->False], ",", 
       InterpretationBox[
        StyleBox["X",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`X[],
        Editable->False]}], "]"}], "2"]}], 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Chi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Chi][],
        Editable->False], ",", 
       InterpretationBox[
        StyleBox["X",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`X[],
        Editable->False]}], "]"}], "2"]}], 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False]], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "d"], 
      SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SuperscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`b][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["\[Del]", "c"], 
      SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Delta]\[CurlyPhi][]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Chi][]],
    Editable->False], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.810983041700263*^9, 3.810983441201518*^9, 
  3.8111363696789293`*^9, 3.8111372920127916`*^9, 3.8119919163379273`*^9, 
  3.811992609007209*^9, 3.8154784945538216`*^9, 3.8154788571899366`*^9}]
}, Open  ]],

Cell[TextData[{
 "It can be checked that there are no more ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Del]", "b"], 
    RowBox[{
     SubscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}]}], 
   TraditionalForm]]],
 " terms appearing in the evolution equation for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["h", "~"], "bc"], TraditionalForm]]],
 " (",
 StyleBox["EE1LHdskhTilde",
  FontSlant->"Italic"],
 "). We remove the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Del]", "d"], 
    RowBox[{
     SuperscriptBox["\[Del]", "d"], 
     OverscriptBox["h", "~"]}]}], TraditionalForm]]],
 " in the evolution equation for ",
 Cell[BoxData[
  FormBox["\[Delta]\[CurlyPhi]", TraditionalForm]]],
 " using the trace equation. This leads to..."
}], "Text",
 CellChangeTimes->{{3.8109666122152843`*^9, 3.810966620409391*^9}, {
  3.8109667911673107`*^9, 3.8109668072066584`*^9}, {3.8109668619185696`*^9, 
  3.810966966757551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BoxTracehLHdsk", "=", 
    RowBox[{"IndexRule", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "c_"}], "]"}], "[", 
       RowBox[{
        RowBox[{"CD", "[", "c_", "]"}], "[", 
        RowBox[{"htilde", "[", 
         RowBox[{"b_", ",", 
          RowBox[{"-", "b_"}]}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "c"}], "]"}], "[", 
         RowBox[{
          RowBox[{"CD", "[", "c", "]"}], "[", 
          RowBox[{"htilde", "[", 
           RowBox[{"b", ",", 
            RowBox[{"-", "b"}]}], "]"}], "]"}], "]"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"EE1TraceLHdskhTilde", "\[Equal]", "0"}], "//", 
            "ScreenDollarIndices"}], ",", 
           RowBox[{
            RowBox[{"CD", "[", 
             RowBox[{"-", "c"}], "]"}], "[", 
            RowBox[{
             RowBox[{"CD", "[", "c", "]"}], "[", 
             RowBox[{"htilde", "[", 
              RowBox[{"b", ",", 
               RowBox[{"-", "b"}]}], "]"}], "]"}], "]"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SimpX", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "s_"}], "]"}], "[", 
         RowBox[{"\[Chi]", "[", "]"}], "]"}], 
        RowBox[{
         RowBox[{"CD", "[", "s_", "]"}], "[", 
         RowBox[{"\[Chi]", "[", "]"}], "]"}]}], "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"-", "2"}], 
        RowBox[{"X", "[", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "s_"}], "]"}], "[", 
         RowBox[{
          RowBox[{"CD", "[", 
           RowBox[{"-", "j_"}], "]"}], "[", 
          RowBox[{"\[Chi]", "[", "]"}], "]"}], "]"}], 
        RowBox[{
         RowBox[{"CD", "[", "s_", "]"}], "[", 
         RowBox[{"\[Chi]", "[", "]"}], "]"}]}], "\[RuleDelayed]", 
       RowBox[{"-", 
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "j"}], "]"}], "[", 
         RowBox[{"X", "[", "]"}], "]"}]}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricCone", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"EE1LHdskhTilde", "//", "Expand"}], ")"}], "/.", 
          RowBox[{
           RowBox[{"htilde", "[", 
            RowBox[{"x_", ",", 
             RowBox[{"-", "x_"}]}], "]"}], "\[RuleDelayed]", 
           RowBox[{"htilde", "[", 
            RowBox[{"s", ",", 
             RowBox[{"-", "s"}]}], "]"}]}]}], "/.", "SimpX"}], "/.", 
        "SimpX"}], "//", "CollectPert"}], ")"}], "/.", "ToGaugehTilde"}], "/.", 
    RowBox[{
     RowBox[{"Z", "[", "_", "]"}], "\[Rule]", "0"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ScalarCone", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"SFE1LHdskhTilde", "/.", "BoxTracehLHdsk"}], "//", 
                "ToCanonical"}], "//", "Simplification"}], "//", 
              "ContractMetric"}], "//", "CollectPert"}], ")"}], "/.", 
           RowBox[{
            RowBox[{"htilde", "[", 
             RowBox[{"x_", ",", 
              RowBox[{"-", "x_"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"htilde", "[", 
             RowBox[{"j", ",", 
              RowBox[{"-", "j"}]}], "]"}]}]}], "/.", "SimpX"}], "/.", 
         "SimpX"}], "//", "CollectPert"}], ")"}], "/.", "ToGaugehTilde"}], "/.", 
     RowBox[{
      RowBox[{"Z", "[", "_", "]"}], "\[Rule]", "0"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"MetricCone", "//", "Get2ndDerivatives"}], ")"}], "\[Equal]", 
  "0"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"ScalarCone", "//", "Get2ndDerivatives"}], ")"}], "\[Equal]", 
  "0"}]}], "Input",
 CellChangeTimes->{{3.810966999440988*^9, 3.810967099234435*^9}, 
   3.8109672378579645`*^9, {3.8109674546322656`*^9, 3.810967465442634*^9}, {
   3.810967835309883*^9, 3.8109679334645514`*^9}, {3.810968472881197*^9, 
   3.8109685216974664`*^9}, {3.8109687306136923`*^9, 3.810968760953816*^9}, {
   3.8109689867117558`*^9, 3.81096898923503*^9}, {3.810983067660631*^9, 
   3.810983096469698*^9}, {3.8109831659267917`*^9, 3.8109831835569177`*^9}, {
   3.81547865169779*^9, 3.8154786881904936`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  StyleBox[\\\"h\
\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"~\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[\
OverscriptBox[\\n  StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"~\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\[Delta]\[CurlyPhi])\"\>", "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], GridBox[{
         {
          OverscriptBox["h", "~"], 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`htilde[-$CellContext`b, -$CellContext`c]]],
     Editable->False]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.810983154672784*^9, 3.8109832354007444`*^9, 
  3.810983497609171*^9, 3.811137355272525*^9, 3.8119919211177244`*^9, 
  3.8119926720901623`*^9, 3.8154786205985003`*^9, 3.8154786993949766`*^9, 
  3.815478888867177*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  StyleBox[\\\"h\
\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"~\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[\
OverscriptBox[\\n  StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"~\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\[Delta]\[CurlyPhi])\"\>", "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], GridBox[{
         {
          OverscriptBox["h", "~"], 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`htilde[-$CellContext`b, -$CellContext`c]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], 
        SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Delta]\[CurlyPhi][]]],
      Editable->False], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Chi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Chi][],
         Editable->False], ",", 
        InterpretationBox[
         StyleBox["X",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`X[],
         Editable->False]}], "]"}], "2"]}], 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["X",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`X[],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "c"], 
        SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`c][
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Delta]\[CurlyPhi][]]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Chi][]],
      Editable->False], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Chi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Chi][],
         Editable->False], ",", 
        InterpretationBox[
         StyleBox["X",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`X[],
         Editable->False]}], "]"}], "2"]}], 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False]], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "X"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`X[]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["X",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`X[],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.810983154672784*^9, 3.8109832354007444`*^9, 
  3.810983497609171*^9, 3.811137355272525*^9, 3.8119919211177244`*^9, 
  3.8119926720901623`*^9, 3.8154786205985003`*^9, 3.8154786993949766`*^9, 
  3.815478888955923*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["These are Eqs. (D.2) and (D.3)",
  FontSlant->"Italic"],
 ". The resulting equations are disgusting to display completely. But as \
shown above ",
 StyleBox["Eq95LHdsk",
  FontSlant->"Italic"],
 " is of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Del]", "d"], 
     RowBox[{
      SuperscriptBox["\[Del]", "d"], 
      SubscriptBox[
       OverscriptBox["h", "~"], "bc"]}]}], "=", 
    RowBox[{
     SubscriptBox["\[Del]", "d"], 
     RowBox[{
      SuperscriptBox["\[Del]", "d"], 
      RowBox[{
       SubscriptBox[
        OverscriptBox["h", "~"], "bc"], "[", 
       RowBox[{"O", "(", 
        RowBox[{
         RowBox[{"\[Del]", 
          OverscriptBox["h", "~"]}], ",", " ", 
         RowBox[{"\[Del]", "\[Delta]\[CurlyPhi]"}]}], ")"}], "]"}]}]}]}], 
   TraditionalForm]]],
 ". Also, ",
 StyleBox["Eq96LHdsk",
  FontSlant->"Italic"],
 " has a term ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Del]", "d"], 
    RowBox[{
     SuperscriptBox["\[Del]", "d"], 
     SubscriptBox[
      OverscriptBox["h", "~"], "bc"]}]}], TraditionalForm]]],
 " which can be removed using ",
 StyleBox["Eq95LHdsk",
  FontSlant->"Italic"],
 ", leading to a final functional expression ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ScriptCapitalG]", "bc"], 
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}]}]}], "=", 
    RowBox[{
     SuperscriptBox["\[ScriptCapitalG]", "bc"], 
     RowBox[{
      SubscriptBox["\[Del]", "b"], 
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       RowBox[{"\[Delta]\[CurlyPhi]", "[", 
        RowBox[{"O", "(", 
         RowBox[{
          RowBox[{"\[Del]", 
           OverscriptBox["h", "~"]}], ",", " ", 
          RowBox[{"\[Del]", "\[Delta]\[CurlyPhi]"}]}], ")"}], "]"}]}]}]}]}], 
   TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ScriptCapitalG]", "bc"], TraditionalForm]]],
 " draws the propagation cone of the scalar perturbation ",
 Cell[BoxData[
  FormBox["\[Delta]\[CurlyPhi]", TraditionalForm]]],
 ". Since this is the general result, let\[CloseCurlyQuote]s just simplify \
the scalar evolution equation to..."
}], "Text",
 CellChangeTimes->{{3.810967195790638*^9, 3.810967247139367*^9}, {
  3.8109673211012473`*^9, 3.8109673233999076`*^9}, {3.8109673914674697`*^9, 
  3.810967519422349*^9}, {3.8109831316188993`*^9, 3.810983134401133*^9}, {
  3.8109831906056833`*^9, 3.810983267582988*^9}, {3.8109838595951567`*^9, 
  3.8109838605486574`*^9}, {3.8109839561267858`*^9, 3.810983998669626*^9}, {
  3.8109846551863804`*^9, 3.8109846553754015`*^9}, {3.815478776364814*^9, 
  3.8154787995937595`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"ScalarCone", "//", "Get2ndDerivatives"}], ")"}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "b_"}], "]"}], "[", 
       RowBox[{
        RowBox[{"CD", "[", "b_", "]"}], "[", 
        RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], "]"}], "]"}], 
      "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "s"}], "]"}], "[", 
       RowBox[{
        RowBox[{"CD", "[", "s", "]"}], "[", 
        RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], "]"}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "s"}], "]"}], "[", 
       RowBox[{
        RowBox[{"CD", "[", "s", "]"}], "[", 
        RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "_"}], "]"}], "[", 
       RowBox[{
        RowBox[{"CD", "[", 
         RowBox[{"-", "_"}], "]"}], "[", 
        RowBox[{"\[Delta]\[CurlyPhi]", "[", "]"}], "]"}], "]"}]}], "}"}], ",",
     "ToCanonical"}], "]"}], "\[Equal]", "0"}]], "Input",
 CellChangeTimes->{{3.810984012643448*^9, 3.810984120239834*^9}, {
   3.810984444809622*^9, 3.8109844729746714`*^9}, {3.810984608156255*^9, 
   3.8109846107205644`*^9}, 3.8154787520359387`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\<\"O(\[Del]\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  StyleBox[\\\"h\
\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"~\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\[Del]\[Delta]\[CurlyPhi],\\!\\(\\*\\nStyleBox[\
OverscriptBox[\\n  StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"~\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\[Delta]\[CurlyPhi])\"\>", "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], GridBox[{
         {
          OverscriptBox["h", "~"], 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`htilde[-$CellContext`b, -$CellContext`c]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      InterpretationBox[
       StyleBox["X",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`X[],
       Editable->False]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "s"], 
       SuperscriptBox["\[Del]", "s"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`s][
      $CellContext`CD[$CellContext`s][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           InterpretationBox[
            StyleBox["\[Chi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Chi][],
            Editable->False], ",", 
           InterpretationBox[
            StyleBox["X",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`X[],
            Editable->False]}], "]"}], "2"]}], 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox["\[Chi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Chi][],
         Editable->False], ",", 
        InterpretationBox[
         StyleBox["X",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`X[],
         Editable->False]}], "]"}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "X"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`X[]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["X",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`X[],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Delta]\[CurlyPhi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Delta]\[CurlyPhi][]]],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[$CellContext`c][
           $CellContext`\[Chi][]],
          Editable->False], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            InterpretationBox[
             StyleBox["\[Chi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Chi][],
             Editable->False], ",", 
            InterpretationBox[
             StyleBox["X",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`X[],
             Editable->False]}], "]"}], "2"]}], 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`X[],
          Editable->False]}], "]"}]}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.8109841214743004`*^9, 3.810984475615695*^9, 
  3.810984611393088*^9, 3.8111373555633383`*^9, 3.8119919213178005`*^9, 
  3.8119926724397106`*^9, 3.81547875286451*^9, 3.8154788891734796`*^9}]
}, Open  ]],

Cell[TextData[{
 "This expression explicitly shows the terms, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[ScriptCapitalG]", "bc"], 
    RowBox[{
     SubscriptBox["\[Del]", "b"], 
     RowBox[{
      SubscriptBox["\[Del]", "c"], "\[Delta]\[CurlyPhi]"}]}]}], 
   TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[ScriptCapitalG]", "bc"], "\[NotEqual]", 
    SuperscriptBox["g", "bc"]}], TraditionalForm]]],
 ", that pushes the propagation of the scalar perturbation ",
 Cell[BoxData[
  FormBox["\[Delta]\[CurlyPhi]", TraditionalForm]]],
 " away from the light cone."
}], "Text",
 CellChangeTimes->{{3.8109846459490356`*^9, 3.810984734525544*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{776, 822},
WindowMargins->{{933, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"ReverseColor.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 234, 3, 70, "Section"],
Cell[817, 27, 707, 14, 87, "Text"],
Cell[CellGroupData[{
Cell[1549, 45, 393, 6, 49, "Subsection"],
Cell[1945, 53, 152, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[2122, 59, 1938, 57, 304, "Input"],
Cell[CellGroupData[{
Cell[4085, 120, 2425, 34, 22, "Print"],
Cell[6513, 156, 2691, 41, 22, "Print"],
Cell[9207, 199, 2446, 34, 40, "Print"],
Cell[11656, 235, 2405, 33, 22, "Print"],
Cell[14064, 270, 2384, 33, 22, "Print"],
Cell[16451, 305, 2423, 34, 22, "Print"],
Cell[18877, 341, 2701, 42, 22, "Print"],
Cell[21581, 385, 2446, 34, 40, "Print"],
Cell[24030, 421, 2425, 34, 22, "Print"],
Cell[26458, 457, 2692, 41, 22, "Print"],
Cell[29153, 500, 2492, 35, 40, "Print"],
Cell[31648, 537, 2422, 34, 22, "Print"],
Cell[34073, 573, 2580, 36, 58, "Print"],
Cell[36656, 611, 2423, 34, 22, "Print"],
Cell[39082, 647, 2665, 41, 22, "Print"],
Cell[41750, 690, 2749, 42, 22, "Print"],
Cell[44502, 734, 2852, 42, 22, "Print"],
Cell[47357, 778, 2810, 42, 22, "Print"],
Cell[50170, 822, 2826, 42, 22, "Print"],
Cell[52999, 866, 2757, 42, 22, "Print"],
Cell[55759, 910, 2767, 42, 22, "Print"],
Cell[58529, 954, 2917, 47, 22, "Print"],
Cell[61449, 1003, 3019, 49, 22, "Print"],
Cell[64471, 1054, 2992, 48, 22, "Print"],
Cell[67466, 1104, 3010, 48, 22, "Print"],
Cell[70479, 1154, 2841, 44, 22, "Print"],
Cell[73323, 1200, 2965, 48, 22, "Print"],
Cell[76291, 1250, 2983, 49, 22, "Print"],
Cell[79277, 1301, 3007, 49, 22, "Print"],
Cell[82287, 1352, 2927, 47, 22, "Print"],
Cell[85217, 1401, 2434, 34, 22, "Print"],
Cell[87654, 1437, 2806, 42, 22, "Print"],
Cell[90463, 1481, 2436, 34, 22, "Print"],
Cell[92902, 1517, 2939, 47, 22, "Print"],
Cell[95844, 1566, 2992, 48, 22, "Print"],
Cell[98839, 1616, 2933, 47, 22, "Print"],
Cell[101775, 1665, 2823, 43, 22, "Print"],
Cell[104601, 1710, 2569, 38, 22, "Print"],
Cell[107173, 1750, 2561, 38, 22, "Print"],
Cell[109737, 1790, 2573, 38, 22, "Print"],
Cell[112313, 1830, 2827, 43, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[115167, 1877, 616, 14, 69, "Text"],
Cell[115786, 1893, 18026, 436, 2120, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[133849, 2334, 477, 11, 41, "Subsection"],
Cell[134329, 2347, 292, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[134646, 2354, 2797, 74, 223, "Input"],
Cell[CellGroupData[{
Cell[137468, 2432, 1058, 18, 22, "Print"],
Cell[138529, 2452, 1061, 18, 22, "Print"],
Cell[139593, 2472, 1059, 18, 22, "Print"],
Cell[140655, 2492, 1079, 19, 22, "Print"]
}, Open  ]],
Cell[141749, 2514, 4742, 125, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146528, 2644, 204, 3, 37, "Subsubsection"],
Cell[146735, 2649, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[146861, 2654, 2892, 88, 209, "Input"],
Cell[149756, 2744, 929, 16, 22, "Print"]
}, Open  ]],
Cell[150700, 2763, 237, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[150962, 2772, 1364, 38, 109, "Input"],
Cell[CellGroupData[{
Cell[152351, 2814, 522, 11, 22, "Print"],
Cell[152876, 2827, 711, 15, 22, "Print"]
}, Open  ]],
Cell[153602, 2845, 4963, 125, 46, "Output"],
Cell[158568, 2972, 12845, 402, 89, "Output"]
}, Open  ]],
Cell[171428, 3377, 122, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[171575, 3382, 1356, 39, 108, "Input"],
Cell[172934, 3423, 1022, 19, 22, "Print"],
Cell[173959, 3444, 19253, 569, 146, "Output"]
}, Open  ]],
Cell[193227, 4016, 124, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[193376, 4021, 725, 18, 50, "Input"],
Cell[194104, 4041, 20400, 694, 125, "Output"]
}, Open  ]],
Cell[214519, 4738, 448, 9, 49, "Text"],
Cell[CellGroupData[{
Cell[214992, 4751, 1087, 33, 89, "Input"],
Cell[216082, 4786, 732, 14, 22, "Print"],
Cell[216817, 4802, 3586, 99, 46, "Output"],
Cell[220406, 4903, 1878, 55, 46, "Output"]
}, Open  ]],
Cell[222299, 4961, 253, 7, 30, "Text"],
Cell[222555, 4970, 1962, 53, 284, "Input"],
Cell[224520, 5025, 569, 16, 52, "Text"],
Cell[CellGroupData[{
Cell[225114, 5045, 2141, 65, 217, "Input"],
Cell[CellGroupData[{
Cell[227280, 5114, 523, 10, 22, "Print"],
Cell[227806, 5126, 595, 13, 22, "Print"],
Cell[228404, 5141, 599, 13, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[229030, 5158, 452, 13, 49, "Text"],
Cell[CellGroupData[{
Cell[229507, 5175, 3021, 87, 226, "Input"],
Cell[232531, 5264, 527, 11, 22, "Print"],
Cell[233061, 5277, 17573, 477, 92, "Output"]
}, Open  ]],
Cell[250649, 5757, 2592, 59, 94, "Text"],
Cell[253244, 5818, 5389, 151, 365, "Input"],
Cell[258636, 5971, 456, 12, 52, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[259129, 5988, 475, 14, 34, "Subsubsection"],
Cell[259607, 6004, 314, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[259946, 6015, 237, 4, 50, "Input"],
Cell[260186, 6021, 17622, 547, 146, "Output"],
Cell[277811, 6570, 18861, 673, 125, "Output"]
}, Open  ]],
Cell[296687, 7246, 365, 12, 34, "Text"],
Cell[CellGroupData[{
Cell[297077, 7262, 2556, 67, 362, "Input"],
Cell[299636, 7331, 14583, 463, 116, "Output"],
Cell[314222, 7796, 6607, 207, 85, "Output"],
Cell[320832, 8005, 19547, 677, 166, "Output"]
}, Open  ]],
Cell[340394, 8685, 332, 11, 38, "Text"],
Cell[CellGroupData[{
Cell[340751, 8700, 2249, 60, 359, "Input"],
Cell[343003, 8762, 7402, 206, 54, "Output"],
Cell[350408, 8970, 3527, 93, 54, "Output"],
Cell[353938, 9065, 24141, 841, 206, "Output"]
}, Open  ]],
Cell[378094, 9909, 974, 32, 71, "Text"],
Cell[CellGroupData[{
Cell[379093, 9945, 4883, 140, 382, "Input"],
Cell[383979, 10087, 2238, 54, 54, "Output"],
Cell[386220, 10143, 18115, 619, 174, "Output"]
}, Open  ]],
Cell[404350, 10765, 2756, 84, 163, "Text"],
Cell[CellGroupData[{
Cell[407131, 10853, 1382, 39, 89, "Input"],
Cell[408516, 10894, 16607, 538, 230, "Output"]
}, Open  ]],
Cell[425138, 11435, 706, 22, 49, "Text"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

