(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    733373,      19145]
NotebookOptionsPosition[    721187,      18804]
NotebookOutlinePosition[    721759,      18824]
CellTagsIndexPosition[    721716,      18821]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Linear perturbations of a stealth black hole in ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence"
}], "Section",
 CellChangeTimes->{3.7733152431446114`*^9}],

Cell[TextData[{
 "\tWe use ",
 ButtonBox["xPert",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.xact.es/xPert/index.html"], None},
  ButtonNote->"http://www.xact.es/xPert/index.html"],
 " and ",
 ButtonBox["xCoba",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.xact.es/xCoba/index.html"], None},
  ButtonNote->"http://www.xact.es/xCoba/index.html"],
 " to efficiently study the linear gravitational perturbations on top of the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence stealth black hole presented in ",
 ButtonBox["arXiv:1802.08606",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1802.08606"], None},
  ButtonNote->"https://arxiv.org/abs/1802.08606"],
 ". This supports the calculations in Section IV of ",
 ButtonBox["arXiv:2007.06006",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2007.06006"], None},
  ButtonNote->"https://arxiv.org/abs/2007.06006"],
 ".\n\nAuthors: ",
 StyleBox[ButtonBox["Reggie Bernardo",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reggiebernardo.weebly.com/"], None},
  ButtonNote->"https://reggiebernardo.weebly.com/"],
  FontSlant->"Italic"],
 " and ",
 StyleBox[ButtonBox["Ian Vega",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://ianvega.wixsite.com/ianvega"], None},
  ButtonNote->"https://ianvega.wixsite.com/ianvega"],
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.7640401685563574`*^9, 3.7640402108201447`*^9}, {
  3.76404058914036*^9, 3.7640406142743535`*^9}, {3.7640428695021496`*^9, 
  3.764042897760912*^9}, {3.7651097554604225`*^9, 3.7651097558496704`*^9}, {
  3.773313214957367*^9, 3.7733133067994843`*^9}, {3.773313341145874*^9, 
  3.773313363781763*^9}, {3.815449245348379*^9, 3.815449273641469*^9}, {
  3.815449420610773*^9, 3.8154494206117697`*^9}, {3.8154494551013703`*^9, 
  3.815449503476261*^9}, {3.8154495493328056`*^9, 3.81544956409032*^9}, {
  3.815449649144905*^9, 3.815449665003645*^9}, {3.815449701670721*^9, 
  3.8154497227309437`*^9}, {3.815449759536707*^9, 3.815449760327593*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["0. Setup",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.815457755556565*^9, 3.815457757195772*^9}}],

Cell[TextData[{
 "\tFirst, we setup xPert to obtain covariant expressions for the linearized \
field equations of ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence theory. We thus define a manifold, metric, scalar field, and ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence potential ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.764040645949489*^9, 3.764040666638496*^9}, {
   3.7733134095019865`*^9, 3.7733134955101404`*^9}, 3.773315216673257*^9, {
   3.81544979304233*^9, 3.815449810506531*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"import", " ", "xPert"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"<<", "xAct`xPert`"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$PrePrint", "=", "ScreenDollarIndices"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Options", "[", "MakeRule", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Options", "[", "ContractMetric", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"org", "[", "expr_", "]"}], ":=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"ContractMetric", "[", "expr", "]"}], ",", 
      "$PerturbationParameter", ",", "ToCanonical"}], "]"}]}], 
   RowBox[{"(*", 
    RowBox[{
    "organizes", " ", "expression", " ", "perturbation", " ", "order"}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "manifold", " ", "and", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dim", "=", "4"}], ";"}], "                                  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefManifold", "[", 
     RowBox[{"Md", ",", "dim", ",", 
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "i", ",", "j", ",", 
        "k", ",", "l", ",", "u", ",", "v"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefMetric", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"g", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], ",", "CD", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}], ",", 
      RowBox[{"WeightedWithBasis", "\[Rule]", "AIndex"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
     "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"define", " ", "scalar", " ", "field", " ", "and", " ", "k"}], 
     "-", 
     RowBox[{"essence", " ", "potential"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "]"}], ",", "Md"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "Q", "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "bookkeeping", " ", "parameter", " ", "for", " ", "GR", " ", "pieces"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7640407744771357`*^9, 3.764040797237398*^9}, {
   3.7733133906815205`*^9, 3.7733134013437567`*^9}, {3.7733135036479645`*^9, 
   3.7733136461538267`*^9}, {3.7733140765215254`*^9, 3.773314095415901*^9}, 
   3.7733145823247566`*^9, {3.77331980106966*^9, 3.77331980129852*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580520243196`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580520388207`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052047971*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052054851*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580521329703`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052138913*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580521457295`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052149803*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523073397`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.6\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.6", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052313191*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523192053`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.81545805232366*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523315444`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052335444*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523411016`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052346988*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052351678*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052357097*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523617897`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "Md", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", 
   "manifold ", $CellContext`Md, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523677735`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentMd", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentMd, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523723145`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523767595`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523825407`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523881493`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag\[Dagger][-$CellContext`a, -$CellContext`b, \
-$CellContext`c, -$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580523955297`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CD", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.81545805240069*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580524054303`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580524097185`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052415634*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580524211216`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052424084*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580524300632`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580524348264`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052440081*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580524788566`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580525826125`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580525988216`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.8154580526146374`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052747491*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052771098*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052786479*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Phi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Phi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052791504*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "Q", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`Q, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052795253*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.76404081966326*^9, 3.764043016376594*^9, 
  3.764044172596425*^9, 3.7640455366886578`*^9, 3.7640499700550537`*^9, 
  3.7640632604510703`*^9, 3.7655834036649733`*^9, 3.765595231391122*^9, 
  3.765597799467574*^9, 3.7655989908057365`*^9, 3.7656041926932364`*^9, 
  3.7656299081840544`*^9, 3.7656789560083537`*^9, 3.773314607317709*^9, 
  3.7733152578840294`*^9, 3.773317275873408*^9, 3.7733176694065323`*^9, 
  3.773319610956815*^9, 3.7733198119497094`*^9, 3.7733200058425384`*^9, 
  3.7733660275286674`*^9, 3.7733681207627735`*^9, 3.7733683145488467`*^9, 
  3.7733706438842487`*^9, 3.7733711294560146`*^9, 3.7733712815438595`*^9, 
  3.773375930165226*^9, 3.8154501100934033`*^9, 3.81545155029101*^9, 
  3.8154574134865484`*^9, 3.8154578847220488`*^9, 3.815458052799765*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "We use the following code from the notebook ",
 StyleBox["ActionVariation_Metric_Fields.nb",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 " available in ",
 ButtonBox["https://github.com/xAct-contrib/examples",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://github.com/xAct-contrib/examples"], None},
  ButtonNote->"https://github.com/xAct-contrib/examples"],
 " to derive the field equations from the Lagrangian:"
}], "Text",
 CellChangeTimes->{{3.815449846247489*^9, 3.8154499150309677`*^9}, {
  3.8154500774752197`*^9, 3.815450083422312*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Cyril", " ", 
    RowBox[{"Pitrou", "'"}], "s", " ", "code"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g_", "?", "MetricQ"}], "[", 
        RowBox[{
         RowBox[{"a_", "?", "UpIndexQ"}], ",", 
         RowBox[{"b_", "?", "UpIndexQ"}]}], "]"}], "|", 
       RowBox[{
        RowBox[{"g_", "?", "MetricQ"}], "[", 
        RowBox[{
         RowBox[{"a_", "?", "DownIndexQ"}], ",", 
         RowBox[{"b_", "?", "DownIndexQ"}]}], "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pertexpr", ",", "res", ",", "dgloc", ",", 
        RowBox[{"(*", 
         RowBox[{"dummyloc", ","}], "*)"}], "hp"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "We", " ", "define", " ", "the", " ", "metric", " ", "perturbation"}],
         ",", " ", 
        RowBox[{"if", " ", "not", " ", "defined", " ", "already"}]}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dgloc", "=", 
        RowBox[{"SymbolJoin", "[", 
         RowBox[{"\"\<\[Delta]\>\"", ",", "g"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"hp", "=", 
        RowBox[{"Head", "@", 
         RowBox[{"Perturbation", "[", 
          RowBox[{"g", "[", 
           RowBox[{
            RowBox[{"DownIndex", "@", "a"}], ",", 
            RowBox[{"DownIndex", "@", "b"}]}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"hp", "===", "Perturbation"}], ",", 
         RowBox[{"DefMetricPerturbation", "[", 
          RowBox[{"g", ",", "dgloc", ",", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<\[Epsilon]\>\"", ",", "g"}], "]"}]}], "]"}], ",", 
         RowBox[{"dgloc", "=", "hp"}]}], "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "We", " ", "perturb", " ", "wrt", " ", "to", " ", "the", " ", 
           "metric", " ", "and", " ", "if", " ", "it", " ", "is", " ", "the", 
           " ", "inverse", " ", "metric", " ", "we", " ", "put", " ", "a", 
           " ", "minus", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"pertexpr", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"DownIndexQ", "[", "a", "]"}], ",", "1", ",", 
                RowBox[{"-", "1"}]}], "]"}], ")"}], "*", 
             RowBox[{"ToCanonical", "@", 
              RowBox[{"ContractMetric", "@", 
               RowBox[{"ExpandPerturbation", "@", 
                RowBox[{"Perturbation", "[", "expr", "]"}]}]}]}]}], "/.", 
            RowBox[{
             RowBox[{"Perturbation", "[", "tens_", "]"}], "\[RuleDelayed]", 
             "0"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"We", " ", "then", " ", "use", " ", 
            RowBox[{"VarD", ".", " ", "It"}], " ", "happens", " ", "that", 
            " ", "some", " ", "trivial", " ", "Kronecker", " ", "appear", " ",
             "which", " ", "need", " ", "to", " ", "be", " ", "handle", " ", 
            "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dgloc", "[", 
                    RowBox[{
                    RowBox[{"LI", "[", "1", "]"}], ",", "a", ",", "b"}], 
                    "]"}], ",", 
                   RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}], "[", 
                 "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", "xTensorQ"}], ",", "covd_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "dummyloc", ",", "pertexpr", ",", "inds"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
           "We", " ", "use", " ", "a", " ", "dummy", " ", "name", " ", "for", 
            " ", "the", " ", "variation", " ", "of", " ", "the", " ", 
            "tensor"}], ",", " ", 
           RowBox[{
           "and", " ", "use", " ", "it", " ", "to", " ", "replace", " ", 
            "the", " ", "formal", " ", "first", " ", "order", " ", 
            "perturbation", " ", "the", " ", "tensor"}]}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "So", " ", "first", " ", "we", " ", "define", " ", "this", " ", 
           "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"dummyloc", "=", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"inds", "=", 
           RowBox[{"DummyIn", "/@", 
            RowBox[{"SlotsOfTensor", "[", "tensor", "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
            RowBox[{"DefTensor", "[", 
             RowBox[{
              RowBox[{"dummyloc", "@@", "inds"}], ",", 
              RowBox[{"First", "@", 
               RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
           RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "Then", " ", "we", " ", "perturb", " ", "the", " ", "action", " ", 
            "and", " ", "replace", " ", 
            RowBox[{"Perturbation", "[", 
             RowBox[{"Tensor", "[", "..", "]"}], "]"}], " ", "by", " ", 
            "this", " ", "dummy", " ", "tensor"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pertexpr", "=", 
           RowBox[{"(", 
            RowBox[{"ToCanonical", "@", 
             RowBox[{"ContractMetric", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ExpandPerturbation", "@", 
                 RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
                RowBox[{
                 RowBox[{"Perturbation", "[", 
                  RowBox[{
                   RowBox[{"tens_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                   "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
          ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"With", " ", "this", " ", "simple", " ", "head"}], ",", 
            " ", 
            RowBox[{"VarD", " ", "works", " ", 
             RowBox[{"correctly", ".", " ", "Again"}], " ", "we", " ", "need",
              " ", "to", " ", "handel", " ", "some", " ", "trivial", " ", 
             "Kronecker"}]}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dummyloc", "@@", "inds"}], ",", "covd"}], "]"}], 
                 "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "[", "inds___", "]"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"tensor", "[", "inds", "]"}], ",", 
      RowBox[{"CovDOfMetric", "@", 
       RowBox[{"First", "@", "$Metrics"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"tensor_", "?", "xTensorQ"}], "[", "inds___", "]"}], ",", 
      "covd_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "dummyloc", ",", "pertexpr"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"dummyloc", "=", 
           RowBox[{"SymbolJoin", "[", 
            RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
            RowBox[{"DefTensor", "[", 
             RowBox[{
              RowBox[{"dummyloc", "[", "inds", "]"}], ",", 
              RowBox[{"First", "@", 
               RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
           RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"Perturbation", " ", "with", " ", "xPert"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pertexpr", "=", 
           RowBox[{"(", 
            RowBox[{"ToCanonical", "@", 
             RowBox[{"ContractMetric", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"ExpandPerturbation", "@", 
                 RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
                RowBox[{
                 RowBox[{"Perturbation", "[", 
                  RowBox[{
                   RowBox[{"tens_", "?", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                   "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "VarD", " ", "and", " ", "removal", " ", "of", " ", 
            "KroneckerDelta"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", "=", 
           RowBox[{"ToCanonical", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"SameDummies", "@", 
               RowBox[{"ContractMetric", "@", 
                RowBox[{
                 RowBox[{"VarD", "[", 
                  RowBox[{
                   RowBox[{"dummyloc", "[", "inds", "]"}], ",", "covd"}], 
                  "]"}], "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
             RowBox[{
              RowBox[{"delta", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"LI", "[", "n_", "]"}]}], ",", 
                RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"NoScalar", "[", "n", "]"}], ",", 
                RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"g_", "?", "MetricQ"}], "[", 
       RowBox[{"as__", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"UpIndexQ", "[", "#", "]"}], "||", 
            RowBox[{"DownIndexQ", "[", "#", "]"}]}], ")"}], "&"}], ")"}]}], 
       "]"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "sqrtg", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sqrtg", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"SignDetOfMetric", "[", "g", "]"}], 
          RowBox[{
           RowBox[{"Determinant", "[", "g", "]"}], "[", "]"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"ToCanonical", "[", 
        RowBox[{
         RowBox[{"PerturbAction", "[", 
          RowBox[{"expr", ",", 
           RowBox[{"g", "[", "as", "]"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"ReplaceDummies", "@", "expr"}], "*", 
          RowBox[{
           RowBox[{"PerturbAction", "[", 
            RowBox[{"sqrtg", ",", 
             RowBox[{"g", "[", "as", "]"}]}], "]"}], "/", "sqrtg"}]}]}], " ", 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}], ",", 
      RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", "tensor", ",", 
      RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"expr_", ",", 
       RowBox[{"tensor_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
            RowBox[{"Not", "[", 
             RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
         ")"}]}]}], "]"}], ":=", 
     RowBox[{"VarAction", "[", 
      RowBox[{"expr", ",", "tensor", ",", 
       RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{
       RowBox[{"tensor_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
            RowBox[{"Not", "[", 
             RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
         ")"}]}], "[", "inds___", "]"}], ",", 
      RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
    RowBox[{"PerturbAction", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"tensor", "[", "inds", "]"}], ",", 
      RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"expr_", ",", 
       RowBox[{
        RowBox[{"tensor_", "?", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
             RowBox[{"Not", "[", 
              RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
          ")"}]}], "[", "inds___", "]"}]}], "]"}], ":=", 
     RowBox[{"VarAction", "[", 
      RowBox[{"expr", ",", 
       RowBox[{"tensor", "[", "inds", "]"}], ",", 
       RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["I. ",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["k",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["-essence theory",
  FontColor->RGBColor[1, 0.5, 0.5]]
}], "Subsection",
 CellChangeTimes->{{3.8154577682379236`*^9, 3.8154577730404625`*^9}, 
   3.815457861968334*^9}],

Cell[TextData[{
 "The ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence Lagrangian is defined as..."
}], "Text",
 CellChangeTimes->{{3.764041358186518*^9, 3.7640414664704266`*^9}, {
  3.764042924090413*^9, 3.7640429583561006`*^9}, {3.765595260060114*^9, 
  3.7655952959116096`*^9}, {3.7733146521368427`*^9, 3.7733146720959005`*^9}, {
  3.8154501241353455`*^9, 3.815450126303156*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"L\[Phi]", "=", 
   RowBox[{"Q", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "b"}], "]"}], "@", 
       RowBox[{"\[Phi]", "[", "]"}]}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"CD", "[", "b", "]"}], "@", 
       RowBox[{"\[Phi]", "[", "]"}]}], "/", "2"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LEH", "=", 
   RowBox[{"\[Kappa]", " ", 
    RowBox[{"RicciScalarCD", "[", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"L", "=", 
    RowBox[{"L\[Phi]", "+", "LEH"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<L\>\"", "\[Equal]", "L"}]}], "Input",
 CellChangeTimes->{{3.764041478859988*^9, 3.7640415539969983`*^9}, {
   3.7640415842731957`*^9, 3.7640417843906937`*^9}, {3.7640427554528036`*^9, 
   3.7640428100625052`*^9}, 3.764043060768496*^9, {3.7655953123826694`*^9, 
   3.7655953879317756`*^9}, {3.773314677019885*^9, 3.7733147460971975`*^9}, {
   3.7733149732657604`*^9, 3.773314975852343*^9}, 3.7733706529299126`*^9, 
   3.8154501296904526`*^9}],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["Q",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q,
     Editable->False], "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]],
      Editable->False]}], "]"}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{
  3.7640418396225977`*^9, {3.764042794843155*^9, 3.764042811797239*^9}, {
   3.764043051746503*^9, 3.764043061728173*^9}, 3.764044185235381*^9, 
   3.7640455464407964`*^9, 3.764049981723111*^9, 3.7640632732449245`*^9, 
   3.7655834157309246`*^9, 3.7655953047870593`*^9, {3.7655953429483757`*^9, 
   3.7655953646717396`*^9}, 3.765597814901467*^9, 3.7655990105198784`*^9, 
   3.765604209211776*^9, 3.765629941346422*^9, 3.765678974457131*^9, 
   3.773314747745637*^9, 3.773314976352801*^9, 3.7733152657586355`*^9, 
   3.7733172859559355`*^9, 3.773317678010567*^9, 3.773319618267468*^9, 
   3.7733198211415477`*^9, 3.773320018495205*^9, 3.773366040494365*^9, 
   3.7733681329240913`*^9, 3.7733683154527473`*^9, 3.7733706673847766`*^9, 
   3.773371136266919*^9, 3.7733712824655123`*^9, 3.7733759310905533`*^9, 
   3.8154501326016006`*^9, 3.8154515586611404`*^9, 3.8154574144194794`*^9, 
   3.8154578856469765`*^9, 3.815458052967158*^9}]
}, Open  ]],

Cell["The Einstein equation is given by...", "Text",
 CellChangeTimes->{{3.7640422043450317`*^9, 3.7640422292151117`*^9}, {
  3.773314905890073*^9, 3.7733149485996275`*^9}, {3.773315040552918*^9, 
  3.7733150408164835`*^9}, {3.815450144906459*^9, 3.8154501457492514`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefTensor", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}], ",", "Md", ",", 
     RowBox[{"Symmetric", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"VarAction", "[", 
          RowBox[{"L", ",", 
           RowBox[{"g", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}], "]"}], "//", "ContractMetric"}],
         "//", "RicciToEinstein"}], "//", "ToCanonical"}], "//", "NoScalar"}],
      ")"}], "/.", 
    RowBox[{
     RowBox[{"Scalar", "[", "expr_", "]"}], "\[RuleDelayed]", "expr"}]}]}], 
  ";", 
  RowBox[{"EE", "\[Equal]", 
   FractionBox[
    RowBox[{"T", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], "2"]}]}]}], "Input",
 CellChangeTimes->{{3.7640422984553337`*^9, 3.764042307144582*^9}, {
  3.7733149248273196`*^9, 3.773314958494128*^9}, {3.7733150071107416`*^9, 
  3.7733150112680798`*^9}, {3.8154501478116884`*^9, 3.8154501482485275`*^9}, {
  3.815450192483181*^9, 3.8154502895908756`*^9}, {3.81545032193789*^9, 
  3.815450342466262*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"T", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`T[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773315274844597*^9, 3.773317286371027*^9, 
  3.773317678233873*^9, 3.77331961863072*^9, 3.7733198213770494`*^9, 
  3.773320018806266*^9, 3.773366040759925*^9, 3.7733681330924206`*^9, 
  3.773368315549214*^9, 3.7733706774803314`*^9, 3.773371136438784*^9, 
  3.773371282527999*^9, 3.773375931135731*^9, 3.8154502064000654`*^9, 
  3.8154503449269447`*^9, 3.8154515588479843`*^9, 3.8154574144561796`*^9, 
  3.81545788568962*^9, 3.815458053030553*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]g", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon]g, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773315274844597*^9, 3.773317286371027*^9, 
  3.773317678233873*^9, 3.77331961863072*^9, 3.7733198213770494`*^9, 
  3.773320018806266*^9, 3.773366040759925*^9, 3.7733681330924206`*^9, 
  3.773368315549214*^9, 3.7733706774803314`*^9, 3.773371136438784*^9, 
  3.773371282527999*^9, 3.773375931135731*^9, 3.8154502064000654`*^9, 
  3.8154503449269447`*^9, 3.8154515588479843`*^9, 3.8154574144561796`*^9, 
  3.81545788568962*^9, 3.8154580530448575`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]g", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]g[
    xAct`xTensor`LI["order"], -$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773315274844597*^9, 3.773317286371027*^9, 
  3.773317678233873*^9, 3.77331961863072*^9, 3.7733198213770494`*^9, 
  3.773320018806266*^9, 3.773366040759925*^9, 3.7733681330924206`*^9, 
  3.773368315549214*^9, 3.7733706774803314`*^9, 3.773371136438784*^9, 
  3.773371282527999*^9, 3.773375931135731*^9, 3.8154502064000654`*^9, 
  3.8154503449269447`*^9, 3.8154515588479843`*^9, 3.8154574144561796`*^9, 
  3.81545788568962*^9, 3.815458053050721*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "a"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Phi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`a][
        $CellContext`\[Phi][]],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "a"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Phi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`a][
        $CellContext`\[Phi][]],
       Editable->False]}], "]"}]}]}], "\[Equal]", 
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`T[-$CellContext`a, -$CellContext`b],
    Editable->False], "2"]}]], "Output",
 CellChangeTimes->{
  3.764042236088004*^9, 3.764042991629761*^9, 3.7640430844720263`*^9, 
   3.76404419606584*^9, 3.7640455555868216`*^9, 3.764049990540106*^9, 
   3.7640632905220957`*^9, 3.765583429404025*^9, 3.765595444828689*^9, 
   3.76559782711736*^9, 3.7655990214548197`*^9, 3.765604217166937*^9, 
   3.765629950183978*^9, 3.7656789815492196`*^9, {3.773314959226824*^9, 
   3.773315012372303*^9}, 3.773315275033079*^9, 3.7733172866201105`*^9, 
   3.7733176784256454`*^9, 3.773319618902492*^9, 3.773319821581339*^9, 
   3.773320019088368*^9, 3.7733660409942455`*^9, 3.7733681332856693`*^9, 
   3.77336831572307*^9, 3.773370677683202*^9, 3.77337113662621*^9, 
   3.7733712826842127`*^9, 3.7733759313096695`*^9, 3.8154502066285315`*^9, 
   3.8154503450968575`*^9, 3.8154515590356417`*^9, 3.815457414635919*^9, 
   3.815457885879119*^9, 3.815458053211382*^9}]
}, Open  ]],

Cell["and the scalar field equation is given by...", "Text",
 CellChangeTimes->{{3.764043210934701*^9, 3.7640432161342635`*^9}, {
  3.7733150444994307`*^9, 3.7733150524362125`*^9}, {3.8154503548381295`*^9, 
  3.8154503550349407`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SE", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"VarAction", "[", 
         RowBox[{"L", ",", 
          RowBox[{"\[Phi]", "[", "]"}]}], "]"}], "//", "ContractMetric"}], "//",
        "ToCanonical"}], "//", "NoScalar"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"Scalar", "[", "expr_", "]"}], "\[RuleDelayed]", "expr"}]}]}], 
  ";", 
  RowBox[{"SE", "\[Equal]", "0"}]}]], "Input",
 CellChangeTimes->{{3.764043265681262*^9, 3.764043269068035*^9}, {
  3.7733150551918793`*^9, 3.7733150656298685`*^9}, {3.81545021343478*^9, 
  3.8154502316414676`*^9}, {3.815450348077243*^9, 3.8154503502319264`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "a"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Phi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`a][
        $CellContext`\[Phi][]],
       Editable->False]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Q",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Q,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "a"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Phi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`a][
        $CellContext`\[Phi][]],
       Editable->False]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7640432264535275`*^9, 3.7640442044431486`*^9, 
  3.76404556367175*^9, 3.764050000139815*^9, 3.764063301003994*^9, 
  3.765583452161162*^9, 3.765595482871152*^9, 3.765597836099633*^9, 
  3.765599028484426*^9, 3.7656042298358493`*^9, 3.7656299580921326`*^9, 
  3.765678990816456*^9, 3.7733150667102423`*^9, 3.7733152779684443`*^9, 
  3.7733172868631477`*^9, 3.77331767861984*^9, 3.773319619182754*^9, 
  3.7733198218009186`*^9, 3.7733200193838615`*^9, 3.773366041181732*^9, 
  3.773368133478488*^9, 3.773368315909585*^9, 3.7733706813542156`*^9, 
  3.773371136782423*^9, 3.7733712828248034`*^9, 3.7733759314510326`*^9, 
  3.815450220095552*^9, 3.8154503583514314`*^9, 3.815451559199123*^9, 
  3.8154574148219337`*^9, 3.815457886062416*^9, 3.815458053375803*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["II. Linearized k-essence on a stealth black hole",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.8154577830577965`*^9, 3.815457795072592*^9}}],

Cell[TextData[{
 "\tWe linearize the field equations and write down the resulting expressions \
in static and spherically-symmetric background.\n\nWe start by defining the \
perturbations ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["h", "ab"], ",", " ", "\[Psi]"}], ")"}], TraditionalForm]]],
 " as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "ab"], "=", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "_"], "ab"], "+", 
     SubscriptBox["h", "ab"]}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "=", 
    RowBox[{
     OverscriptBox["\[Phi]", "_"], "+", "\[Psi]"}]}], TraditionalForm]]],
 " in ",
 StyleBox["xPert",
  FontSlant->"Italic"],
 "..."
}], "Text",
 CellChangeTimes->{{3.7640431506860847`*^9, 3.7640431793601103`*^9}, {
   3.764043418865844*^9, 3.764043467137682*^9}, {3.7733153067632055`*^9, 
   3.7733153387457576`*^9}, 3.7733162963879757`*^9, {3.7786611011722956`*^9, 
   3.778661101618695*^9}, 3.8154504062838*^9, {3.815450438743067*^9, 
   3.81545050496823*^9}, {3.8154579944104753`*^9, 3.815457995573468*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefMetricPerturbation", "[", 
   RowBox[{"g", ",", "h", ",", "\[Epsilon]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Unprotect", "[", "IndexForm", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"IndexForm", "[", 
    RowBox[{"LI", "[", "x_", "]"}], "]"}], ":=", 
   RowBox[{"ColorString", "[", 
    RowBox[{
     RowBox[{"ToString", "[", "x", "]"}], ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "IndexForm", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IndexForm", "[", 
   RowBox[{"LI", "[", "n", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensorPerturbation", "[", 
   RowBox[{
    RowBox[{"\[Psi]", "[", 
     RowBox[{"LI", "[", "order", "]"}], "]"}], ",", 
    RowBox[{"\[Phi]", "[", "]"}], ",", "Md"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7640441579067197`*^9, 3.7640441600154533`*^9}, {
  3.7733153830674543`*^9, 3.7733153905617623`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.764043484379655*^9, 3.76404421110468*^9, 3.76404556981987*^9, 
   3.7640500143554773`*^9, 3.7640633075337334`*^9, 3.7655834618976045`*^9, 
   3.76559557043641*^9, 3.765597857329047*^9, 3.765599051650891*^9, 
   3.7656042583291893`*^9, 3.765629976702411*^9, 3.76567900631513*^9, {
   3.7733153855022125`*^9, 3.7733153916288347`*^9}, 3.7733172923614388`*^9, 
   3.7733177153291883`*^9, 3.773319627517304*^9, 3.7733198272637396`*^9, 
   3.7733200235034723`*^9, 3.7733660483946514`*^9, 3.7733681558150535`*^9, 
   3.7733683159156704`*^9, 3.773370686931037*^9, 3.7733711425310755`*^9, 
   3.773371282856045*^9, 3.7733759314643564`*^9, 3.8154508661356936`*^9, 
   3.815451565863451*^9, 3.8154574148445373`*^9, 3.815457886089198*^9, 
   3.8154580534279294`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`h[
    xAct`xTensor`LI["order"], -$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.764043484379655*^9, 3.76404421110468*^9, 3.76404556981987*^9, 
   3.7640500143554773`*^9, 3.7640633075337334`*^9, 3.7655834618976045`*^9, 
   3.76559557043641*^9, 3.765597857329047*^9, 3.765599051650891*^9, 
   3.7656042583291893`*^9, 3.765629976702411*^9, 3.76567900631513*^9, {
   3.7733153855022125`*^9, 3.7733153916288347`*^9}, 3.7733172923614388`*^9, 
   3.7733177153291883`*^9, 3.773319627517304*^9, 3.7733198272637396`*^9, 
   3.7733200235034723`*^9, 3.7733660483946514`*^9, 3.7733681558150535`*^9, 
   3.7733683159156704`*^9, 3.773370686931037*^9, 3.7733711425310755`*^9, 
   3.773371282856045*^9, 3.7733759314643564`*^9, 3.8154508661356936`*^9, 
   3.815451565863451*^9, 3.8154574148445373`*^9, 3.815457886089198*^9, 
   3.8154580534316177`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Psi]", "[", 
    RowBox[{"LI", "[", "\<\"order\"\>", "]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Psi][
    xAct`xTensor`LI["order"]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.764043484379655*^9, 3.76404421110468*^9, 3.76404556981987*^9, 
   3.7640500143554773`*^9, 3.7640633075337334`*^9, 3.7655834618976045`*^9, 
   3.76559557043641*^9, 3.765597857329047*^9, 3.765599051650891*^9, 
   3.7656042583291893`*^9, 3.765629976702411*^9, 3.76567900631513*^9, {
   3.7733153855022125`*^9, 3.7733153916288347`*^9}, 3.7733172923614388`*^9, 
   3.7733177153291883`*^9, 3.773319627517304*^9, 3.7733198272637396`*^9, 
   3.7733200235034723`*^9, 3.7733660483946514`*^9, 3.7733681558150535`*^9, 
   3.7733683159156704`*^9, 3.773370686931037*^9, 3.7733711425310755`*^9, 
   3.773371282856045*^9, 3.7733759314643564`*^9, 3.8154508661356936`*^9, 
   3.815451565863451*^9, 3.8154574148445373`*^9, 3.815457886089198*^9, 
   3.8154580534371824`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. Simplifying rules", "Subsubsection",
 CellChangeTimes->{{3.815450845929494*^9, 3.815450860445957*^9}}],

Cell[TextData[{
 "To make the results more aesthetically pleasing, we replace the \
perturbations by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[ScriptH]", "ab"], ",", "\[Delta]\[Psi]"}], ")"}], 
   TraditionalForm]]],
 " after linearizing the expressions using ",
 StyleBox["xPert",
  FontSlant->"Italic"],
 "..."
}], "Text",
 CellChangeTimes->{
  3.764043725840581*^9, {3.7733158953413057`*^9, 3.7733159130123706`*^9}, {
   3.8154509134616394`*^9, 3.815450955984582*^9}, {3.8154511858171577`*^9, 
   3.8154511864371614`*^9}, {3.815458019378091*^9, 3.8154580299292793`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[Delta]\[Psi]", "[", "]"}], ",", "Md"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ruleScalarPert", "=", 
    RowBox[{"IndexRule", "[", 
     RowBox[{
      RowBox[{"\[Psi]", "[", 
       RowBox[{"LI", "[", "1", "]"}], "]"}], ",", 
      RowBox[{"\[Delta]\[Psi]", "[", "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[ScriptH]", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "Md", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<\[ScriptH]\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert1", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", 
       RowBox[{"-", "a_"}], ",", 
       RowBox[{"-", "b_"}]}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert2", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", 
       RowBox[{"-", "a_"}], ",", "b_"}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", "b"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert3", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", "a_", ",", 
       RowBox[{"-", "b_"}]}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{"a", ",", 
       RowBox[{"-", "b"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert4", "=", 
   RowBox[{"IndexRule", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"LI", "[", "1", "]"}], ",", "a_", ",", "b_"}], "]"}], ",", 
     RowBox[{"\[ScriptH]", "[", 
      RowBox[{"a", ",", "b"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleMetricPert", "=", 
   RowBox[{"{", 
    RowBox[{
    "ruleMetricPert1", ",", "ruleMetricPert2", ",", "ruleMetricPert3", ",", 
     "ruleMetricPert4"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.773315821220405*^9, {3.8154509640480814`*^9, 3.8154509644266434`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]\[Psi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]\[Psi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8154510065408278`*^9, 3.8154515708373947`*^9, 
  3.81545741490819*^9, 3.815457886179553*^9, 3.815458053467785*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptH]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8154510065408278`*^9, 3.8154515708373947`*^9, 
  3.81545741490819*^9, 3.815457886179553*^9, 3.8154580534713354`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "The following set of rules also aesthetically simplify the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence potential and its derivatives on the stealth background (where the \
kinetic density is constant)..."
}], "Text",
 CellChangeTimes->{{3.8154511799573183`*^9, 3.8154511921687613`*^9}, {
  3.815451270641152*^9, 3.815451304593172*^9}, {3.815451343075885*^9, 
  3.815451349107713*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"Q0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*OverscriptBox[\(K\), \(_\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"QX0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(_\)], \(X\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"QXX0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(_\)], \(XX\)]\)\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"QXXX0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[OverscriptBox[\(K\), \(_\)], \(XXX\)]\)\>\""}]}],
    "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SimpQ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["Q",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Q,
        Editable->False], "[", "expr_", "]"}], "\[RuleDelayed]", "Q0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], "'"}], "[", "expr_", "]"}], "\[RuleDelayed]", 
      "QX0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], "''"}], "[", "expr_", "]"}], "\[RuleDelayed]", 
      "QXX0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["Q",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Q,
         Editable->False], "'''"}], "[", "expr_", "]"}], "\[RuleDelayed]", 
      "QXXX0"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.81545120324049*^9, 3.8154512557918863`*^9}, {
  3.815451381037484*^9, 3.8154513817821946`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", "Q0",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`Q0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.815451570879492*^9, 3.8154574149500465`*^9, 
  3.815457886229288*^9, 3.815458053515303*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "QX0", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`QX0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.815451570879492*^9, 3.8154574149500465`*^9, 
  3.815457886229288*^9, 3.8154580535182767`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "QXX0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`QXX0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.815451570879492*^9, 3.8154574149500465`*^9, 
  3.815457886229288*^9, 3.8154580535229626`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "QXXX0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`QXXX0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.815451570879492*^9, 3.8154574149500465`*^9, 
  3.815457886229288*^9, 3.8154580535301723`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "B. ",
 StyleBox["Linearized field equations: ",
  FontSize->18,
  FontColor->RGBColor[1, 0.5, 0]],
 StyleBox["covariant",
  FontSize->18,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0]]
}], "Subsubsection",
 CellChangeTimes->{{3.8154510781694975`*^9, 3.815451093031909*^9}, {
  3.815451364107044*^9, 3.8154513644707127`*^9}}],

Cell["The linearized Einstein equation is given by...", "Text",
 CellChangeTimes->{{3.7733164372611885`*^9, 3.7733164506169176`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EEO1", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Perturbed", "[", 
            RowBox[{"EE", ",", "1"}], "]"}], "//", "ExpandPerturbation"}], "//",
           "ContractMetric"}], "//", "NoScalar"}], "//", "ToCanonical"}], "//",
        "org"}], ")"}], "/.", "SimpQ"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"EEO1", "\[Equal]", 
  FractionBox[
   RowBox[{"T", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "2"]}]}], "Input",
 CellChangeTimes->{{3.773316452150737*^9, 3.7733165335172906`*^9}, {
   3.7733166061901207`*^9, 3.773316964773902*^9}, {3.773317054300076*^9, 
   3.7733170838813686`*^9}, {3.7733171265462976`*^9, 3.773317241125397*^9}, {
   3.7733173322616644`*^9, 3.7733173660413322`*^9}, 3.773317429345099*^9, {
   3.7733178620369453`*^9, 3.773317863903512*^9}, {3.7733180755838027`*^9, 
   3.7733181012362003`*^9}, {3.815451427701024*^9, 3.815451449593315*^9}, {
   3.81545159777701*^9, 3.815451628885064*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox["K", "_"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q0,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "X"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QX0,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox["K", "_"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Q0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], "c", "d"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], $CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"R", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["R",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciScalarCD[],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], "c", " "},
                {" ", " ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`h[
           xAct`xTensor`LI[1], $CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", "c"},
                {" ", "b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`h[
           xAct`xTensor`LI[1], -$CellContext`b, $CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", "c"},
                {" ", "a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`h[
           xAct`xTensor`LI[1], -$CellContext`a, $CellContext`c]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", " "},
                {" ", "a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`h[
           xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], "c", "d"},
                {" ", " ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`h[
           xAct`xTensor`LI[1], $CellContext`c, $CellContext`d]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], "c", " "},
                {" ", " ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`h[
           xAct`xTensor`LI[1], $CellContext`c, -$CellContext`c]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False]}]}], ")"}]}]}], "\[Equal]", 
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`T[-$CellContext`a, -$CellContext`b],
    Editable->False], "2"]}]], "Output",
 CellChangeTimes->{{3.7733164961696005`*^9, 3.7733165342083693`*^9}, {
   3.773316608812399*^9, 3.773316634867557*^9}, 3.7733166738131676`*^9, 
   3.773316852585021*^9, 3.773317430087282*^9, 3.77331774391146*^9, 
   3.7733178648307*^9, {3.7733180927482595`*^9, 3.7733181025945024`*^9}, 
   3.7733196284008207`*^9, 3.7733198445977187`*^9, 3.7733200407988944`*^9, 
   3.773366065781175*^9, 3.7733681709320574`*^9, 3.7733683164124837`*^9, 
   3.7733708124791875`*^9, 3.7733711540752473`*^9, 3.7733712832934437`*^9, 
   3.7733759319066267`*^9, 3.8154514535813255`*^9, 3.8154515132883153`*^9, {
   3.815451593345092*^9, 3.8154515997134104`*^9}, 3.815451629748701*^9, 
   3.815457415334228*^9, 3.8154578866211357`*^9, 3.8154580540516047`*^9}]
}, Open  ]],

Cell["\<\
On the other hand, the linearized scalar field equation is... \
\>", "Text",
 CellChangeTimes->{{3.7733177581221867`*^9, 3.7733177748562236`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SEO1", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Perturbed", "[", 
            RowBox[{"SE", ",", "1"}], "]"}], "//", "ExpandPerturbation"}], "//",
           "ContractMetric"}], "//", "NoScalar"}], "//", "ToCanonical"}], "//",
        "org"}], ")"}], "/.", "SimpQ"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"SEO1", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.773316554181466*^9, 3.7733165551340275`*^9}, {
  3.7733165895907974`*^9, 3.7733165921820974`*^9}, {3.773316978861601*^9, 
  3.7733170127883263`*^9}, {3.7733177814809113`*^9, 3.773317852391872*^9}, {
  3.7733180517413683`*^9, 3.773318055320876*^9}, {3.773318088784252*^9, 
  3.773318109531026*^9}, {3.8154514618095946`*^9, 3.815451473347475*^9}, {
  3.8154516030275316`*^9, 3.815451620203373*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "X"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QX0,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], 
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "XX"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QXX0,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], 
          SuperscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Psi][
           xAct`xTensor`LI[1]]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], "b", " "},
                {" ", " ", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`h[
          xAct`xTensor`LI[1], $CellContext`b, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", "b"},
                {" ", "a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`h[
          xAct`xTensor`LI[1], -$CellContext`a, $CellContext`b]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "X"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], "a", "b"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], $CellContext`a, $CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Psi][
           xAct`xTensor`LI[1]]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", "c"},
               {" ", "a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]], " ", " "},
                {" ", "a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`h[
          xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XXX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[Psi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[1., 0., 0.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Psi][
          xAct`xTensor`LI[1]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox[
         SubscriptBox[
          OverscriptBox["K", "_"], "XXX"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`QXXX0,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[1., 0., 0.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`a][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Phi][]],
        Editable->False]}]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.77331659273783*^9, {3.773316995265541*^9, 3.773317013791396*^9}, {
   3.7733178060967736`*^9, 3.7733178533586245`*^9}, 3.773318110978798*^9, 
   3.7733196290244527`*^9, 3.7733198486561003`*^9, 3.773320043949954*^9, 
   3.773366069858305*^9, 3.7733681740225625`*^9, 3.7733683170065084`*^9, 
   3.7733708268039556`*^9, 3.773371170212697*^9, 3.7733712837152195`*^9, 
   3.7733759322719574`*^9, 3.815451476963441*^9, 3.815451635032276*^9, 
   3.815457415773058*^9, 3.815457887103012*^9, 3.8154580545678177`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["C. The stealth black hole",
 FontSize->18,
 FontColor->RGBColor[1, 0.5, 0]]], "Subsubsection",
 CellChangeTimes->{
  3.8154516551737366`*^9, {3.8154526218629*^9, 3.8154526262910166`*^9}, {
   3.815453235185811*^9, 3.81545323573948*^9}, {3.8154542740950713`*^9, 
   3.815454276841241*^9}, {3.8154557036815033`*^9, 3.8154557069064426`*^9}}],

Cell[TextData[{
 "We present the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence stealth black hole of ",
 ButtonBox["arXiv:1802.08606",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1802.08606"], None},
  ButtonNote->"https://arxiv.org/abs/1802.08606"],
 " and evaluate the linearized field equations on this background.\n \nWe \
start by defining the shift symmetric ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence potential of ",
 ButtonBox["arXiv:1802.08606",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1802.08606"], None},
  ButtonNote->"https://arxiv.org/abs/1802.08606"],
 ":"
}], "Text",
 CellChangeTimes->{{3.773317922565898*^9, 3.773317975146597*^9}, {
  3.773318022970854*^9, 3.773318030578541*^9}, {3.7733755333526373`*^9, 
  3.773375534778934*^9}, {3.81545166442017*^9, 3.815451720466052*^9}, {
  3.815455747313439*^9, 3.8154557710581865`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "\[Beta]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ktfl", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{"b", "+", 
   RowBox[{"2", "\[Beta]", 
    SqrtBox[
     RowBox[{"-", "b"}]]}]}]}]}], "Input",
 CellChangeTimes->{{3.773317976118695*^9, 3.773318019320345*^9}, {
  3.773371062306238*^9, 3.773371063363315*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Beta]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Beta], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733711748054123`*^9, 3.7733712837620883`*^9, 
  3.773375932345396*^9, 3.8154517348770914`*^9, 3.8154574157994413`*^9, 
  3.8154578871338654`*^9, 3.815458054625102*^9}]
}, Open  ]],

Cell[TextData[{
 "In this theory, the background scalar field\[CloseCurlyQuote]s kinetic \
density is constant, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "=", 
    RowBox[{"-", 
     SuperscriptBox["\[Beta]", "2"]}]}], TraditionalForm]]],
 ". The potential and its derivatives on top of this become..."
}], "Text",
 CellChangeTimes->{{3.773318147792363*^9, 3.773318164584118*^9}, {
  3.7733185413235674`*^9, 3.7733185697644353`*^9}, {3.815451850443612*^9, 
  3.815451909453044*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"\[Beta]", ">", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X0", "=", 
   RowBox[{"-", 
    SuperscriptBox["\[Beta]", "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TFLpotentials", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q0", "\[Rule]", 
       RowBox[{"Ktfl", "[", 
        RowBox[{"0", ",", "b"}], "]"}]}], ",", 
      RowBox[{"QX0", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Ktfl", "[", 
          RowBox[{"0", ",", "b"}], "]"}], ",", "b"}], "]"}]}], ",", 
      RowBox[{"QXX0", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Ktfl", "[", 
          RowBox[{"0", ",", "b"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"b", ",", "2"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"QXXX0", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Ktfl", "[", 
          RowBox[{"0", ",", "b"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"b", ",", "3"}], "}"}]}], "]"}]}]}], "}"}], "/.", 
    RowBox[{"b", "\[Rule]", "X0"}]}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7733181776401653`*^9, 3.7733185143265195`*^9}, {
  3.7733710683066726`*^9, 3.7733710906142445`*^9}, {3.815451814549035*^9, 
  3.815451833310079*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox["K", "_"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q0,
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Beta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Beta],
      Editable->False], "2"]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "X"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QX0,
     Editable->False], "\[Rule]", "0"}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "XX"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QXX0,
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"]}]]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      SubscriptBox[
       OverscriptBox["K", "_"], "XXX"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`QXXX0,
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["3", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "4"]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7733183281893315`*^9, 3.7733183488233476`*^9}, {
   3.773318398741041*^9, 3.7733184430906334`*^9}, 3.77331851678135*^9, 
   3.7733196291312313`*^9, 3.773319856470482*^9, 3.773320062454842*^9, 
   3.773366084604828*^9, 3.7733681796167307`*^9, 3.7733683170694284`*^9, 
   3.773370837082799*^9, 3.7733711006583433`*^9, 3.7733711768673887`*^9, 
   3.7733712837933264`*^9, 3.773375932395916*^9, 3.8154519117020288`*^9, 
   3.8154574158393974`*^9, 3.815457887175746*^9, 3.815458054707982*^9}]
}, Open  ]],

Cell["\<\
The Einstein equation and the scalar field equation become...\
\>", "Text",
 CellChangeTimes->{{3.773318590815277*^9, 3.773318611519104*^9}, {
  3.8154519253742857`*^9, 3.815451926340863*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EEtfl", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"EEO1", "/.", "TFLpotentials"}], "/.", "ruleMetricPert"}], "/.", 
    "ruleScalarPert"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SEtfl", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SEO1", "/.", "TFLpotentials"}], "/.", "ruleMetricPert"}], "/.",
      "ruleScalarPert"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"EEtfl", "\[Equal]", 
  FractionBox[
   RowBox[{"T", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "2"]}], "\[IndentingNewLine]", 
 RowBox[{"SEtfl", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.7733186137424917`*^9, 3.7733186713160934`*^9}, {
  3.773318736557102*^9, 3.7733187513217587`*^9}, {3.7733192792053895`*^9, 
  3.77331930810187*^9}, {3.8154519318349333`*^9, 3.8154519552986546`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Beta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Beta],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["R",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciScalarCD[],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"R", 
            StyleBox[GridBox[{
               {" ", " "},
               {"c", "d"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][$CellContext`c, $CellContext`d],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "a"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[ScriptH][-$CellContext`b, $CellContext`c]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SubscriptBox["\[Del]", "b"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c]]],
        Editable->False]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], 
          SuperscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[$CellContext`c][
          $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]]],
        Editable->False]}], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[ScriptH][$CellContext`c, $CellContext`d]]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[ScriptH][$CellContext`c, -$CellContext`c]]],
        Editable->False]}], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]]}], ")"}]}]}], "\[Equal]", 
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`T[-$CellContext`a, -$CellContext`b],
    Editable->False], "2"]}]], "Output",
 CellChangeTimes->{
  3.7733186743016424`*^9, {3.7733187426127815`*^9, 3.7733187518577604`*^9}, 
   3.773319308770158*^9, 3.773319629212333*^9, 3.7733198584991565`*^9, 
   3.77332006617548*^9, 3.773366095961528*^9, 3.7733681818405085`*^9, 
   3.773368317129166*^9, 3.773370849673602*^9, 3.7733711821474023`*^9, 
   3.7733712838714657`*^9, 3.7733759324784703`*^9, 3.8154531668283978`*^9, 
   3.8154574159304132`*^9, 3.815457887320257*^9, 3.8154580548377895`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`a][
       $CellContext`\[Phi][]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], 
        SubscriptBox["\[Del]", "a"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Phi][]]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]],
      Editable->False]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Beta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Beta],
       Editable->False], "2"]}]], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], 
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
         Editable->False]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], 
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Phi][]]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"]], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], 
           SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Delta]\[Psi][]]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], 
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]]],
         Editable->False]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"]], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], 
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[$CellContext`c][
           $CellContext`\[Phi][]]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], GridBox[{
             {"\[ScriptH]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"a", "b"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], 
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "4"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "d"], 
           SubscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`d][
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Phi][]]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "4"]}]]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.7733186743016424`*^9, {3.7733187426127815`*^9, 3.7733187518577604`*^9}, 
   3.773319308770158*^9, 3.773319629212333*^9, 3.7733198584991565`*^9, 
   3.77332006617548*^9, 3.773366095961528*^9, 3.7733681818405085`*^9, 
   3.773368317129166*^9, 3.773370849673602*^9, 3.7733711821474023`*^9, 
   3.7733712838714657`*^9, 3.7733759324784703`*^9, 3.8154531668283978`*^9, 
   3.8154574159304132`*^9, 3.815457887320257*^9, 3.815458054875375*^9}]
}, Open  ]],

Cell[TextData[{
 "It is easy to check that the zeroth order terms above are satisfied by a \
constant background kinetic density ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["X", "0"], "=", 
    RowBox[{"-", 
     SuperscriptBox["\[Beta]", "2"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and the anti-de Sitter spacetime (Eqs. (4.1-3)). The linear terms (in the \
perturbation parameter ",
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 ") of the above expression are Eqs. (4.6) and (4.7), respectively, in ",
 ButtonBox["arXiv:2007.06006",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2007.06006"], None},
  ButtonNote->"https://arxiv.org/abs/2007.06006"],
 ".\n\nWe note that the terms in ",
 StyleBox["EEtfl",
  FontSlant->"Italic"],
 " besides ",
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]]],
 " and proportional to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptH]", "ab"], TraditionalForm]]],
 " come from the perturbations of the Einstein tensor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["G", "ab"], TraditionalForm]]],
 ". Let\[CloseCurlyQuote]s just simplify this to make the result mirror Eq. \
(4.6)..."
}], "Text",
 CellChangeTimes->{{3.7733187684378643`*^9, 3.773318803053726*^9}, {
  3.8154519869732027`*^9, 3.8154520028916054`*^9}, {3.815453485575122*^9, 
  3.815453557095356*^9}, {3.815455127836602*^9, 3.8154552129206095`*^9}, {
  3.8154569931714725`*^9, 3.8154570095140047`*^9}, {3.8154575632521143`*^9, 
  3.8154576192672577`*^9}, {3.8154576588753443`*^9, 3.815457692557262*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "define", " ", "perturbation", " ", "of", " ", "the", " ", "Einstein", " ",
     "tensor"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DefTensor", "[", 
    RowBox[{
     RowBox[{"\[Delta]G", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}], ",", "Md", ",", 
     RowBox[{"Symmetric", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"some", " ", "tensor", " ", "for", " ", "replacement"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"DefTensor", "[", 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}], ",", "Md", ",", 
     RowBox[{"Symmetric", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"let", " ", "R", " ", 
      SubscriptBox["\[ScriptH]", "ab"]}], " ", "\[Rule]", " ", 
     SubscriptBox["X", "ab"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R\[ScriptH]ToX", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"RicciScalarCD", "[", "]"}], " ", 
       RowBox[{"\[ScriptH]", "[", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{"-", "b"}]}], "]"}]}], "\[Rule]", 
      RowBox[{"X", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[ScriptH]To\[Delta]G", "=", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Perturbation", "[", 
                 RowBox[{
                  RowBox[{"EinsteinCD", "[", 
                   RowBox[{
                    RowBox[{"-", "a"}], ",", 
                    RowBox[{"-", "b"}]}], "]"}], ",", "1"}], "]"}], "//", 
                "ExpandPerturbation"}], ")"}], "/.", "ruleMetricPert"}], "//",
              "ToCanonical"}], "//", "ContractMetric"}], ")"}], "\[Equal]", 
          RowBox[{"\[Delta]G", "[", 
           RowBox[{
            RowBox[{"-", "a"}], ",", 
            RowBox[{"-", "b"}]}], "]"}]}], "/.", "R\[ScriptH]ToX"}], ",", 
        RowBox[{"X", "[", 
         RowBox[{
          RowBox[{"-", "a"}], ",", 
          RowBox[{"-", "b"}]}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"linearized", " ", "Einstein", " ", "equation", " ", "in", " ", 
     SubscriptBox["\[Delta]G", "ab"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EEtfl\[Delta]G", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"EEtfl", "/.", "R\[ScriptH]ToX"}], "/.", 
        "\[ScriptH]To\[Delta]G"}], "//", "ToCanonical"}], "//", "org"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"EEtfl\[Delta]G", "\[Equal]", 
    FractionBox[
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}], "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.815455227551956*^9, 3.815455342822431*^9}, {
  3.8154553990316644`*^9, 3.815455446188758*^9}, {3.8154554851199813`*^9, 
  3.8154555702197995`*^9}, {3.8154556047063875`*^9, 3.8154556525952935`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]G", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]G[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8154574159970617`*^9, 3.815457887398509*^9, 
  3.8154580549188814`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"X", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`X[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8154574159970617`*^9, 3.815457887398509*^9, 
  3.8154580549225693`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Beta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Beta],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]G", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]G[-$CellContext`a, -$CellContext`b],
        Editable->False]}], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]]}], ")"}]}]}], "\[Equal]", 
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`T[-$CellContext`a, -$CellContext`b],
    Editable->False], "2"]}]], "Output",
 CellChangeTimes->{3.8154553447713785`*^9, 3.8154554075250254`*^9, 
  3.815455546963811*^9, 3.8154556540287495`*^9, 3.815457416195858*^9, 
  3.8154578876012354`*^9, 3.8154580550959454`*^9}]
}, Open  ]],

Cell["The linear terms of the above equation is Eq. (4.6).", "Text",
 CellChangeTimes->{{3.815455789367594*^9, 3.815455805088647*^9}, {
  3.815455841041457*^9, 3.8154558438905463`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "D. Linearized field equations: ",
 StyleBox["component calculations",
  FontSlant->"Italic"]
}], "Subsubsection",
 CellChangeTimes->{{3.815455717312868*^9, 3.8154557267071934`*^9}}],

Cell[TextData[{
 "To put the linearized field equations on the stealth black hole into \
component form, we prepare to use ",
 StyleBox["xCoba",
  FontSlant->"Italic"],
 "..."
}], "Text",
 CellChangeTimes->{
  3.8154551304387302`*^9, {3.815455684939108*^9, 3.8154556918254666`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "xAct`xCoba`"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932546112*^9, 3.815452008859643*^9, 
  3.815457416247137*^9, 3.815457887642006*^9, 3.815458055161316*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xCoba`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.8.4\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xCoba`  version ", "0.8.4", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932546112*^9, 3.815452008859643*^9, 
  3.815457416247137*^9, 3.815457887642006*^9, 3.8154580551680336`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Yllanes and Jose M. \
Martin-Garcia, under the General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932546112*^9, 3.815452008859643*^9, 
  3.815457416247137*^9, 3.815457887642006*^9, 3.8154580551723995`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932546112*^9, 3.815452008859643*^9, 
  3.815457416247137*^9, 3.815457887642006*^9, 3.8154580551750793`*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932546112*^9, 3.815452008859643*^9, 
  3.815457416247137*^9, 3.815457887642006*^9, 3.815458055178978*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7733196293148375`*^9, 3.7733198626157904`*^9, 
  3.7733200696544743`*^9, 3.773366109395896*^9, 3.7733681847937846`*^9, 
  3.7733683171988335`*^9, 3.7733708534695897`*^9, 3.773371198659165*^9, 
  3.77337128393392*^9, 3.773375932546112*^9, 3.815452008859643*^9, 
  3.815457416247137*^9, 3.815457887642006*^9, 3.815458055183413*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "We define a chart ",
 StyleBox["B",
  FontSlant->"Italic"],
 ", with coordinates ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
    "t", ",", " ", "r", ",", " ", "\[Theta]", ",", " ", "\[CurlyPhi]"}], 
    ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", in manifold ",
 StyleBox["Md",
  FontSlant->"Italic"],
 "..."
}], "Text",
 CellChangeTimes->{{3.7733188632772217`*^9, 3.773318900765401*^9}, {
  3.8154520167839656`*^9, 3.8154520300463314`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefChart", "[", 
    RowBox[{"B", ",", "Md", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "[", "]"}], ",", 
       RowBox[{"r", "[", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "]"}], ",", 
       RowBox[{"\[CurlyPhi]", "[", "]"}]}], "}"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"define", " ", "metric", " ", "components"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "M", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", "f0", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f0", "[", "r_", "]"}], "=", 
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{"2", "M"}], "r"], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Beta]", "2"], 
      SuperscriptBox["r", "2"]}], 
     RowBox[{"6", "\[Kappa]"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bg", "=", 
   RowBox[{"f", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"r", ",", 
      RowBox[{"f0", "[", "r", "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TFLbh", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"f", "[", 
          RowBox[{"r", "[", "]"}], "]"}]}], ",", "0", ",", "0", ",", "0"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        FractionBox["1", 
         RowBox[{"f", "[", 
          RowBox[{"r", "[", "]"}], "]"}]], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        SuperscriptBox[
         RowBox[{"r", "[", "]"}], "2"], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]}]}], "}"}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"xCoba", " ", "computes", " ", "curvature", " ", "quantities"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MetricInBasis", "[", 
   RowBox[{"g", ",", 
    RowBox[{"-", "B"}], ",", "TFLbh"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MetricCompute", "[", 
    RowBox[{"g", ",", "B", ",", "All", ",", 
     RowBox[{"CVSimplify", "\[Rule]", "Simplify"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"define", " ", "scalar", " ", "field", " ", "component"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"\[Phi]0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(0\)]\)\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComponentValue", "[", 
   RowBox[{
    RowBox[{"\[Phi]", "[", "]"}], ",", 
    RowBox[{"\[Phi]0", "[", 
     RowBox[{"r", "[", "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7733189181761007`*^9, 3.7733190818323417`*^9}, {
  3.773319233577424*^9, 3.773319248858676*^9}, {3.773319340721227*^9, 
  3.773319341136634*^9}, {3.773319419160674*^9, 3.7733194394219985`*^9}, {
  3.773319542175627*^9, 3.7733195800751348`*^9}, {3.773319867127632*^9, 
  3.773319893193243*^9}, {3.7733199245887737`*^9, 3.7733199351291447`*^9}, {
  3.815452080445979*^9, 3.815452081592728*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefChart", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"chart \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefChart, ": Defining ", "chart ", $CellContext`B, ". ", 
   ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055434353*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"t", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`t[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554384356`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"r", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`r[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554428797`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Theta]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`\[Theta][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055447218*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[CurlyPhi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`\[CurlyPhi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055451518*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", "mapping ", $CellContext`B, 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055455773*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"inverse mapping \"\>", "\[InvisibleSpace]", "iB",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", 
   "inverse mapping ", $CellContext`iB, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554593906`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"diB", "[", 
    RowBox[{
     RowBox[{"-", "\[FormalA]"}], ",", "iBa"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`diB[-\[FormalA], $CellContext`iBa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554639516`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"dB", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", "B\[FormalA]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`dB[-$CellContext`a, $CellContext`B\[FormalA]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055471156*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefBasis", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"basis \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Coordinated basis.\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefBasis, ": Defining ", "basis ", $CellContext`B, ". ", 
   "Coordinated basis."],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554747725`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parallel derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"PDB", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "parallel derivative ", 
   $CellContext`PDB[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554783726`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionPDB", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionPDB[$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554829865`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelPDB", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelPDB[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554872074`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Riemann tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RiemannPDB", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", "d"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>",
    "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Riemann tensor ", 
   $CellContext`RiemannPDB[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554909906`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciPDB", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Ricci tensor ", 
   $CellContext`RicciPDB[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580554964237`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric +1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaUpB", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric +1 density ", 
   $CellContext`etaUpB[$CellContext`a, $CellContext`b, $CellContext`c, \
$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055499967*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric -1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaDownB", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric -1 density ", 
   $CellContext`etaDownB[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580555051413`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`M, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055509235*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "f", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`f, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.81545805551303*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "f0",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`f0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580555166483`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> -$CellContext`f[
      $CellContext`r[]], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580555230017`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580555385695`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580555445538`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580555616765`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580555732436`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    FractionBox["1", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`f[
      $CellContext`r[]]^(-1), " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055581507*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055603943*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580556115685`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.81545805562539*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055638441*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "2"]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`r[]^2, 
   " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580556469727`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580556568346`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580556699476`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055685402*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.81545805570136*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["Sin",
         ShowAutoStyles->False,
         AutoSpacing->False],
        Sin,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Theta]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Theta][],
        Editable->False], "]"}], "2"]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`r[]^2 Sin[
       $CellContext`\[Theta][]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580557086945`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"DetgB", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`DetgB[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580557143354`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCDPDB", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ChristoffelCDPDB[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580557676167`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", 
   "\[Phi]0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`\[Phi]0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.815458055979982*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Phi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Phi][],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[Phi]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[Phi][] -> $CellContext`\[Phi]0[
     $CellContext`r[]], " for tensor ", $CellContext`\[Phi]],
  Editable->False]], "Print",
 CellChangeTimes->{3.773319344088993*^9, 3.773319629648142*^9, 
  3.7733198986848345`*^9, 3.773320072419689*^9, 3.7733661174825506`*^9, 
  3.773368186966484*^9, 3.773368317383882*^9, 3.7733708562658052`*^9, 
  3.773371201767809*^9, 3.7733712841682415`*^9, 3.7733759327363615`*^9, 
  3.815452084886443*^9, 3.8154574168508854`*^9, 3.8154578879824233`*^9, 
  3.8154580559829745`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Decomposing the perturbations in spherical harmonics and Regge-Wheeler \
gauge...\
\>", "Text",
 CellChangeTimes->{{3.773366469600523*^9, 3.7733664720698996`*^9}, {
  3.7733665025152383`*^9, 3.7733665045538893`*^9}, {3.773368063749564*^9, 
  3.77336807844987*^9}, {3.8154521160027437`*^9, 3.8154521302467766`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"spherical", " ", "harmonics"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefConstantSymbol", "/@", 
     RowBox[{"{", 
      RowBox[{"\[Lambda]", ",", "m", ",", "\[Omega]"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"PL", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(P\), \(lm\)]\)\>\""}]}],
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"PL", "''"}], "[", "\[Theta]_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "-", 
          RowBox[{
           SuperscriptBox["m", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], " ", 
       RowBox[{"PL", "[", "\[Theta]", "]"}]}], "-", 
      RowBox[{
       RowBox[{"Cot", "[", "\[Theta]", "]"}], 
       RowBox[{
        RowBox[{"PL", "'"}], "[", "\[Theta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"YLM", ":=", 
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "m", " ", 
        RowBox[{"\[CurlyPhi]", "[", "]"}]}]], 
      RowBox[{"PL", "[", 
       RowBox[{"\[Theta]", "[", "]"}], "]"}], 
      SuperscriptBox["E", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "\[Omega]", " ", 
        RowBox[{"t", "[", "]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"even", " ", "parity", " ", "sector"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"H0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(0\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"H1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(1\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"H2", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(H\), \(2\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"KK", ",", 
      RowBox[{"PrintAs", "\[Rule]", "\"\<K\>\""}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"even", "=", 
     RowBox[{"YLM", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           RowBox[{"H0", "[", 
            RowBox[{"r", "[", "]"}], "]"}]}], ",", 
          RowBox[{"H1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"H1", "[", 
           RowBox[{"r", "[", "]"}], "]"}], ",", 
          FractionBox[
           RowBox[{"H2", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           RowBox[{"f", "[", 
            RowBox[{"r", "[", "]"}], "]"}]], ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"KK", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           SuperscriptBox[
            RowBox[{"r", "[", "]"}], "2"]}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", 
          RowBox[{
           RowBox[{"KK", "[", 
            RowBox[{"r", "[", "]"}], "]"}], 
           SuperscriptBox[
            RowBox[{"r", "[", "]"}], "2"], 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]}]}], "}"}]}], 
       "}"}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"odd", " ", "parity", " ", "sector"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"h0", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(h\), \(0\)]\)\>\""}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", 
     RowBox[{"h1", ",", 
      RowBox[{
      "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(h\), \(1\)]\)\>\""}]}], 
     "]"}], ";", 
    RowBox[{"odd", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[CurlyPhi]", "[", "]"}]}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[CurlyPhi]", "[", "]"}]}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[CurlyPhi]", "[", "]"}]}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"D", "[", 
             RowBox[{"YLM", ",", 
              RowBox[{"\[CurlyPhi]", "[", "]"}]}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "]"}], "]"}]]}], 
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
          RowBox[{"h0", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "]"}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{"YLM", ",", 
            RowBox[{"\[Theta]", "[", "]"}]}], "]"}], 
          RowBox[{"h1", "[", 
           RowBox[{"r", "[", "]"}], "]"}]}], ",", "0", ",", "0"}], "}"}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "define", " ", "\[Eta]", " ", "to", " ", "pick", " ", "up", " ", "odd", 
     " ", "parity", " ", "components"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Eta]", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pert", "=", 
     RowBox[{"even", "+", 
      RowBox[{"\[Eta]", " ", "odd"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"perturbation", " ", "components"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ComponentValue", "[", 
     RowBox[{
      RowBox[{"ComponentArray", "[", 
       RowBox[{"\[ScriptH]", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"{", 
           RowBox[{"b", ",", "B"}], "}"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"{", 
           RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}], "]"}], ",", "pert"}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ChangeComponents", "[", 
     RowBox[{
      RowBox[{"\[ScriptH]", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"b", ",", "B"}], "}"}], ",", 
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}], ",", 
      RowBox[{"\[ScriptH]", "[", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"b", ",", "B"}], "}"}]}], ",", 
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "\[Xi]", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ComponentValue", "[", 
     RowBox[{
      RowBox[{"\[Delta]\[Psi]", "[", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Xi]", "[", 
        RowBox[{"r", "[", "]"}], "]"}], "YLM"}]}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.773366593064456*^9, 3.77336661663792*^9}, {
  3.7733667709425535`*^9, 3.773366779891224*^9}, {3.7733668347114286`*^9, 
  3.7733668348525324`*^9}, {3.773366980015911*^9, 3.7733670108045745`*^9}, {
  3.77336723589386*^9, 3.773367245981041*^9}, {3.7733674722818136`*^9, 
  3.773367561633624*^9}, {3.7733676041279316`*^9, 3.773367670392033*^9}, {
  3.77336771620301*^9, 3.773367803580041*^9}, {3.7733679450121737`*^9, 
  3.773367956001275*^9}, {3.77336800446821*^9, 3.773368013528138*^9}, {
  3.773368285811098*^9, 3.7733682952640667`*^9}, {3.7733712547553983`*^9, 
  3.7733712549899473`*^9}, {3.7733759053881483`*^9, 3.7733759087747154`*^9}, {
  3.7788263279015703`*^9, 3.778826339850498*^9}, {3.815452162497436*^9, 
  3.815452180117135*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Lambda]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Lambda], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580562866383`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", "m", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`m, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056292507*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Omega]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Omega], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580562965837`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "PL",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`PL, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056300466*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "H0",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`H0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056303668*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "H1",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`H1, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056307887*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "H2",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`H2, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056310851*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "KK",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`KK, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580563152018`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "h0",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`h0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056318654*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "h1",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`h1, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.81545805632235*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Eta]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Eta], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580563252754`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`f[
      $CellContext`r[]] $CellContext`H0[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056343706*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "1"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H1,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`H1[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580563679132`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     InterpretationBox[
      StyleBox["m",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`m,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Eta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Eta],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Csc",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Csc,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["h", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> 
   Complex[0, 1] 
    E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`m $CellContext`\[Eta] Csc[
      $CellContext`\[Theta][]] $CellContext`h0[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.81545805638768*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     InterpretationBox[
      StyleBox["\[Eta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Eta],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["h", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Sin",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Sin,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["P", "lm"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`PL,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`\[Eta] $CellContext`h0[
      $CellContext`r[]] Sin[
      $CellContext`\[Theta][]] Derivative[1][$CellContext`PL][
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580564058504`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580564214*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox["\[Omega]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Omega],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox["m",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`m,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[CurlyPhi][],
            Editable->False]}]}], ")"}]}]], " ", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["H", "2"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`H2,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], "]"}], " ", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["P", "lm"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`PL,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Theta]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Theta][],
        Editable->False], "]"}]}], 
     RowBox[{
      InterpretationBox[
       StyleBox["f",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`f,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`f[
       $CellContext`r[]]^(-1) $CellContext`H2[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056437729*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     InterpretationBox[
      StyleBox["m",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`m,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Eta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Eta],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Csc",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Csc,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["h", "1"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h1,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> 
   Complex[0, 1] 
    E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`m $CellContext`\[Eta] Csc[
      $CellContext`\[Theta][]] $CellContext`h1[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056455474*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     InterpretationBox[
      StyleBox["\[Eta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Eta],
      Editable->False], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["h", "1"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h1,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["Sin",
        ShowAutoStyles->False,
        AutoSpacing->False],
       Sin,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["P", "lm"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`PL,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`\[Eta] $CellContext`h1[
      $CellContext`r[]] Sin[
      $CellContext`\[Theta][]] Derivative[1][$CellContext`PL][
      $CellContext`\[Theta][]], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056472188*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056488041*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056502302*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`KK,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "2"]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`KK[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]] $CellContext`r[]^2, 
   " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580565165453`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056527629*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056541696*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056556427*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580565711107`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`KK,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["Sin",
         ShowAutoStyles->False,
         AutoSpacing->False],
        Sin,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Theta]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Theta][],
        Editable->False], "]"}], "2"]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`KK[
      $CellContext`r[]] $CellContext`PL[
      $CellContext`\[Theta][]] $CellContext`r[]^2 Sin[
       $CellContext`\[Theta][]]^2, " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580565861497`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {0, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, $CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       0, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       0, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580566160326`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {0, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       0, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056641968*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {0, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       0, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056667584*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {0, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       0, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{3, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056702135*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{1, $CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     1, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580567162857`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       0, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056751957*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056787614*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056824729*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {1, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       1, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{3, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056867384*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, $CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     2, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580568809977`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       0, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458056914592*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     2, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580569298573`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580569633627`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580569874387`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {2, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       2, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{3, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580570178347`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, $CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     3, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580570326643`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       0, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580570668397`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     3, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458057080571*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.81545805711749*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     3, $CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580571308317`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580571715016`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, $CellContext`B}, {3, $CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[ScriptH]", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[ScriptH][{3, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{0, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{1, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{2, -$CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{3, $CellContext`B}, {
       3, $CellContext`B}] $CellContext`\[ScriptH][{3, -$CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458057200657*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{0, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`\[ScriptH][{0, $CellContext`B}, {
     0, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458057214966*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`\[ScriptH][{0, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580572352986`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{1, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`\[ScriptH][{1, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458057248954*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`\[ScriptH][{0, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458057263581*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`\[ScriptH][{1, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580572730365`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{2, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`\[ScriptH][{2, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580572920732`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`\[ScriptH][{0, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580573091593`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`\[ScriptH][{1, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580573233757`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`\[ScriptH][{2, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458057337364*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[ScriptH]"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`\[ScriptH][{3, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`\[ScriptH][{3, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`\[ScriptH]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580573520794`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computed \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {
             StyleBox["b",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["c",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][{$CellContext`b, $CellContext`B}, \
{-$CellContext`c, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["a",
               FontColor->RGBColor[1., 0., 0.]]},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[{$CellContext`b, $CellContext`B}, {$CellContext`a, \
$CellContext`B}],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"\[ScriptH]", 
          StyleBox[GridBox[{
             {" ", " "},
             {
              StyleBox["a",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["c",
               FontColor->RGBColor[1., 0., 0.]]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[ScriptH][{-$CellContext`a, -$CellContext`B}, \
{-$CellContext`c, -$CellContext`B}],
      Editable->False]}]}], "\[InvisibleSpace]", "\<\" in \"\>", 
   "\[InvisibleSpace]", "0.7695691`7.337792614936196", 
   "\[InvisibleSpace]", "\<\" Seconds\"\>"}],
  SequenceForm[
  "Computed ", $CellContext`\[ScriptH][{$CellContext`b, $CellContext`B}, \
{-$CellContext`c, -$CellContext`B}] -> $CellContext`g[{$CellContext`b, \
$CellContext`B}, {$CellContext`a, $CellContext`B}] \
$CellContext`\[ScriptH][{-$CellContext`a, -$CellContext`B}, {-$CellContext`c, \
-$CellContext`B}], " in ", 0.7695691`7.337792614936196, " Seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580573681417`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", 
   "\[Xi]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`\[Xi], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.815458057372131*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Delta]\[Psi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Delta]\[Psi][],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox["\[Omega]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Omega],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["m",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`m,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[CurlyPhi][],
           Editable->False]}]}], ")"}]}]], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["P", "lm"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`PL,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["\[Theta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Theta][],
       Editable->False], "]"}], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Xi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Xi],
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", 
   "\[Delta]\[Psi]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[Delta]\[Psi][] -> 
   E^(Complex[
       0, -1] ($CellContext`\[Omega] $CellContext`t[] + $CellContext`m \
$CellContext`\[CurlyPhi][])) $CellContext`PL[
      $CellContext`\[Theta][]] $CellContext`\[Xi][
      $CellContext`r[]], " for tensor ", $CellContext`\[Delta]\[Psi]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7733678164999332`*^9, 3.773368194354699*^9, 
  3.7733683180542536`*^9, 3.773370860093605*^9, 3.773371224043871*^9, 
  3.773371284839959*^9, 3.773375933299882*^9, 3.8154522094036913`*^9, 
  3.815457417721367*^9, 3.8154578889273386`*^9, 3.8154580573785152`*^9}]
}, Open  ]]
}, Open  ]],

Cell["The scalar field equation therefore becomes...", "Text",
 CellChangeTimes->{{3.7733678423349247`*^9, 3.773367842953064*^9}, {
  3.7733680866464996`*^9, 3.7733680941529093`*^9}, {3.8154522213052588`*^9, 
  3.815452225458627*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SEcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"SEtfl", ",", "\[Epsilon]"}], "]"}], "//", 
         RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
        "ToValues"}], "//", "ToValues"}], "//", "Simplification"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"SEcomp", "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.815452271884026*^9, 3.815452276339941*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Beta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Beta],
       Editable->False], "4"], " ", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["\[Omega]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Omega],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox["m",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`m,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[CurlyPhi][],
          Editable->False]}]}], ")"}]}]], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["f",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`f,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["P", "lm"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`PL,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["\[Theta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Theta][],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Xi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Xi],
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}], "-", 
         RowBox[{"3", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["H", "2"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`H2,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["f",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`f,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], "2"], " ", 
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["r",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`r[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Xi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Xi],
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["H", "2"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`H2,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox["f",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`f,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Xi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Xi],
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Beta]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Beta],
               Editable->False], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["\[Phi]", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]0,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}], "-", 
            RowBox[{"3", " ", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["f",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`f,
                Editable->False], "\[Prime]",
               MultilineFunction->None], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["\[Phi]", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]0,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", 
               InterpretationBox[
                StyleBox["r",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`r[],
                Editable->False], "]"}], "3"]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Beta]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Beta],
               Editable->False], "2"], " ", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], " ", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 SubscriptBox["\[Phi]", "0"],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]0,
                Editable->False], "\[Prime]\[Prime]",
               MultilineFunction->None], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["r",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`r[],
            Editable->False], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Beta]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Beta],
               Editable->False], "2"], " ", 
             InterpretationBox[
              StyleBox["r",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`r[],
              Editable->False], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["H", "2"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`H2,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["\[Phi]", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Phi]0,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox["\[Xi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Xi],
                   Editable->False], "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[
                SubscriptBox["H", "2"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`H2,
               Editable->False], "[", 
              InterpretationBox[
               StyleBox["r",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`r[],
               Editable->False], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["\[Beta]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Beta],
                  Editable->False], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["\[Phi]", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Phi]0,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}]}], "+", 
               RowBox[{"3", " ", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox["f",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`f,
                   Editable->False], "\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   InterpretationBox[
                    StyleBox[
                    SubscriptBox["\[Phi]", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Phi]0,
                    Editable->False], "\[Prime]",
                   MultilineFunction->None], "[", 
                  InterpretationBox[
                   StyleBox["r",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`r[],
                   Editable->False], "]"}], "3"]}], "-", 
               RowBox[{"20", " ", 
                SuperscriptBox[
                 InterpretationBox[
                  StyleBox["\[Beta]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Beta],
                  Editable->False], "2"], " ", 
                InterpretationBox[
                 StyleBox["r",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`r[],
                 Editable->False], " ", 
                RowBox[{
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    SubscriptBox["\[Phi]", "0"],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Phi]0,
                   Editable->False], "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", 
                 InterpretationBox[
                  StyleBox["r",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`r[],
                  Editable->False], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.773367846720767*^9, 3.773368236425032*^9, 
  3.773368321664221*^9, 3.773370890131996*^9, 3.77337128790174*^9, 
  3.7733759360200152`*^9, 3.8154522815021324`*^9, 3.815457420758128*^9, 
  3.8154578921364493`*^9, 3.815458059626322*^9}]
}, Open  ]],

Cell["We simplify this as follows...", "Text",
 CellChangeTimes->{{3.7733683686658406`*^9, 3.773368374761974*^9}, {
  3.815452303845544*^9, 3.8154523039961786`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"removebrackets", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"t", "[", "]"}], "\[Rule]", "t"}], ",", 
     RowBox[{
      RowBox[{"r", "[", "]"}], "\[Rule]", "r"}], ",", 
     RowBox[{
      RowBox[{"\[Theta]", "[", "]"}], "\[Rule]", "\[Theta]"}], ",", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "[", "]"}], "\[Rule]", "\[CurlyPhi]"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulef", "=", 
   RowBox[{"f", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"r", ",", 
      FractionBox[
       RowBox[{"2", 
        SuperscriptBox["\[Beta]", "2"]}], 
       SuperscriptBox[
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "2"]]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SEcomp2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"SEcomp", "/.", "removebrackets"}], ")"}], "/.", "rulef"}], 
      ")"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Xi]pprule", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"SEcomp2", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Xi]", "''"}], "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Xi]pp", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "''"}], "[", "r", "]"}], "/.", "\[Xi]pprule"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"H2", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"H2", "'"}], "[", "r", "]"}]}], "}"}], ",", "Simplify"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "this", " ", "is", " ", "the", " ", "scalar", " ", "field", " ", 
    "equation"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Xi]''(r)\>\"", "\[Equal]", "\[Xi]pp"}]}], "Input",
 CellChangeTimes->{{3.773368376546979*^9, 3.7733686388495235`*^9}, {
  3.7733687012114677`*^9, 3.773368784233404*^9}, {3.7733688411136017`*^9, 
  3.7733688511355023`*^9}, {3.815452332705621*^9, 3.8154523348567247`*^9}, {
  3.815452381238984*^9, 3.8154523918103495`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Xi]''(r)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["H", "2"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`H2,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["H", "2"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`H2,
      Editable->False], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "r"], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "2"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Xi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Xi],
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "r"]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.7733686406693115`*^9, 3.7733687861726427`*^9, 3.7733688524941397`*^9, 
   3.773370893927984*^9, 3.7733712882766914`*^9, 3.773375936111142*^9, {
   3.815452389051467*^9, 3.8154523928615513`*^9}, 3.8154574208722963`*^9, 
   3.8154578922882633`*^9, 3.8154580597433796`*^9}]
}, Open  ]],

Cell[TextData[{
 "To make this look more like the corresponding expression in ",
 ButtonBox["arXiv:2007.06006",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2007.06006"], None},
  ButtonNote->"https://arxiv.org/abs/2007.06006"],
 ", we simply make the following transformation..."
}], "Text",
 CellChangeTimes->{{3.773376733413616*^9, 3.773376768866003*^9}, {
  3.815452413191839*^9, 3.8154524397183*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefScalarFunction", "[", 
    RowBox[{"hrr", ",", 
     RowBox[{
     "PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(h\), \(rr\)]\)\>\""}]}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sconstraint", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Xi]", "''"}], "[", "r", "]"}], "\[Equal]", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Xi]pp", "/.", 
         RowBox[{"H2", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"hrr", "[", "r", "]"}], 
             RowBox[{"f", "[", "r", "]"}]}]}], "]"}]}]}], "/.", "rulef"}], 
       ")"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"hrr", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"hrr", "'"}], "[", "r", "]"}]}], "}"}], ",", "Simplify"}], 
     "]"}]}]}], ";", "Sconstraint"}]}], "Input",
 CellChangeTimes->{{3.773376797277991*^9, 3.77337692345638*^9}, {
  3.773377129217041*^9, 3.7733771864740677`*^9}, {3.8154524503346725`*^9, 
  3.8154524558824654`*^9}, {3.8154540489879537`*^9, 3.815454073323629*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", 
   "hrr", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`hrr, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8154574209025335`*^9, 3.8154578923274565`*^9, 
  3.8154580597774706`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Xi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Xi],
     Editable->False], "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "r", "]"}], "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Beta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Beta],
       Editable->False], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["h", "rr"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`hrr,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Beta]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Beta],
       Editable->False], "2"], " ", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["h", "rr"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`hrr,
       Editable->False], "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "-", 
       RowBox[{"3", " ", "r", " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
    RowBox[{"r", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "2"]}]], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Xi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Xi],
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "r"]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.7733769064507613`*^9, 3.773377155073775*^9, 
  3.773377187010594*^9, 3.815452489109152*^9, 3.815454073891068*^9, 
  3.815457420906048*^9, 3.815457892335819*^9, 3.8154580597804966`*^9}]
}, Open  ]],

Cell[TextData[{
 "This is ",
 StyleBox["parabolic constraint equation",
  FontSlant->"Italic"],
 " is Eq. (4.9) in ",
 ButtonBox["arXiv:2007.06006",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2007.06006"], None},
  ButtonNote->"https://arxiv.org/abs/2007.06006"],
 " (with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Xi]", "\[Rule]", "\[Psi]"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "). The exact solution of which is given by..."
}], "Text",
 CellChangeTimes->{{3.7733772046812854`*^9, 3.773377216780513*^9}, {
  3.8154524971949406`*^9, 3.815452502739319*^9}, {3.815452561185494*^9, 
  3.8154525996653976`*^9}, {3.815452748597501*^9, 3.8154527675062*^9}, {
  3.8154540381528463`*^9, 3.8154540449830503`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Xi]Toy", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "'"}], "[", "r", "]"}], "\[Rule]", 
       RowBox[{"y", "[", "r", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "''"}], "[", "r", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"y", "'"}], "[", "r", "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Xi]sol", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"Sconstraint", "/.", "\[Xi]Toy"}], ",", "y", ",", "r"}], "]"}], 
    "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "\[Xi]sol"}], "Input",
 CellChangeTimes->{{3.8154540878292685`*^9, 3.8154541116834755`*^9}, {
  3.815454157209814*^9, 3.8154541930859947`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,112,1,16759206551006671906,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8154541937787247`*^9, 3.8154574210617666`*^9, 
  3.8154578925181766`*^9, 3.815458059936411*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"y", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "r", "}"}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["h", "rr"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`hrr,
          Editable->False], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"]}], 
       SuperscriptBox["r", "2"]]}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8154541623772583`*^9, 3.8154541938070717`*^9, 
  3.8154574211379986`*^9, 3.815457892630501*^9, 3.8154580600143423`*^9}]
}, Open  ]],

Cell[TextData[{
 "This is Eq. (4.10) in ",
 ButtonBox["arXiv:2007.06006",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2007.06006"], None},
  ButtonNote->"https://arxiv.org/abs/2007.06006"],
 ". \n\nWe now use the above solution of the constraint equation to simplify \
the scalar field\[CloseCurlyQuote]s SET in the Einstein equation. Recall that \
the Einstein equation in the stealth background is..."
}], "Text",
 CellChangeTimes->{{3.8154542084322577`*^9, 3.8154542392226458`*^9}, {
  3.815454292261216*^9, 3.815454336528551*^9}, {3.8154563739928656`*^9, 
  3.815456389352585*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EEtfl\[Delta]G", "\[Equal]", 
  FractionBox[
   RowBox[{"T", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "2"]}]], "Input",
 CellChangeTimes->{{3.8154543399104176`*^9, 3.815454351539213*^9}, {
  3.8154558813876114`*^9, 3.8154558833087254`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Beta]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Beta],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`a, -$CellContext`b],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Beta]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Beta],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[ScriptH]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH][-$CellContext`a, -$CellContext`b],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]G", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Delta]G[-$CellContext`a, -$CellContext`b],
        Editable->False]}], "-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Delta]\[Psi][]],
         Editable->False]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[ScriptH]", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "a"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[Del]", "b"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`c][
          $CellContext`\[Phi][]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Phi][]],
         Editable->False]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Beta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Beta],
          Editable->False], "2"]}]]}], ")"}]}]}], "\[Equal]", 
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`T[-$CellContext`a, -$CellContext`b],
    Editable->False], "2"]}]], "Output",
 CellChangeTimes->{{3.8154543418525653`*^9, 3.8154543528369794`*^9}, 
   3.81545588416184*^9, 3.8154574211867576`*^9, 3.8154578926862783`*^9, 
   3.8154580600615807`*^9}]
}, Open  ]],

Cell["Extracting the terms determined by the scalar field\[CloseCurlyQuote]s \
SET...", "Text",
 CellChangeTimes->{{3.815454391301409*^9, 3.815454428321415*^9}, {
  3.8154564695433626`*^9, 3.8154564775336375`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SET\[Phi]O1", "=", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EEtfl\[Delta]G", ",", "\[Beta]", ",", 
      RowBox[{"-", "2"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]T\), \(ab\)]\)\>\"", "\[Equal]", 
  "SET\[Phi]O1"}]}], "Input",
 CellChangeTimes->{{3.8154565005352564`*^9, 3.8154565911883698`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]T\\), \\(ab\\)]\\)\"\>", 
  "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Delta]\[Psi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Delta]\[Psi][]],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    InterpretationBox[
     StyleBox["\[Epsilon]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Epsilon],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[ScriptH]", 
         StyleBox[GridBox[{
            {" ", " "},
            {"c", "d"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH][-$CellContext`c, -$CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{{3.815456568483794*^9, 3.815456588802215*^9}, 
   3.8154574212115374`*^9, 3.815457892722086*^9, 3.815458060093617*^9}]
}, Open  ]],

Cell["We reduce this to the 3rd term of Eq. (4.11)...", "Text",
 CellChangeTimes->{{3.815456594072881*^9, 3.8154566171480937`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SET\[Phi]O1comp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"SET\[Phi]O1", "//", 
          RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//",
         "TraceBasisDummy"}], "//", "ToValues"}], "//", "ToValues"}], "//", 
     "ToCanonical"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Delta]T\), \(ab\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"SET\[Phi]O1comp", "/.", 
          RowBox[{"H2", "\[Rule]", 
           RowBox[{"Function", "[", 
            RowBox[{"r", ",", 
             RowBox[{
              RowBox[{"hrr", "[", "r", "]"}], 
              RowBox[{"f", "[", "r", "]"}]}]}], "]"}]}]}], "/.", 
         "removebrackets"}], "/.", "\[Xi]Toy"}], "/.", "\[Xi]sol"}], "/.", 
      "rulef"}], "//", "Simplify"}], "//", "MatrixForm"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8154566436081305`*^9, 3.815456651248625*^9}, {
  3.8154568610299463`*^9, 3.8154568792690306`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]T\\), \\(ab\\)]\\)\"\>", 
  "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "0", "0", "0"},
      {"0", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               InterpretationBox[
                StyleBox["m",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`m,
                Editable->False], " ", "\[CurlyPhi]"}], "+", 
              RowBox[{"t", " ", 
               InterpretationBox[
                StyleBox["\[Omega]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Omega],
                Editable->False]}]}], ")"}]}]], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Beta]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Beta],
            Editable->False], "2"], " ", 
          InterpretationBox[
           StyleBox["\[Epsilon]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Epsilon],
           Editable->False], " ", 
          RowBox[{"C", "[", "1", "]"}], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["P", "lm"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`PL,
            Editable->False], "[", "\[Theta]", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "3"]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["r", "2"]}]]}], "0", "0"},
      {"0", "0", "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{{3.815456874634819*^9, 3.815456879935671*^9}, 
   3.815457421514552*^9, 3.8154578931870174`*^9, 3.815458060403889*^9}]
}, Open  ]],

Cell[TextData[{
 "This obviously corresponds to the remaining terms of the scalar field\
\[CloseCurlyQuote]s SET (i.e., third term of Eq. (4.11) with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"I", "(", 
      RowBox[{"t", ",", "\[Theta]", ",", "\[CurlyPhi]"}], ")"}], "~", 
     SubscriptBox["C", "1"]}], 
    RowBox[{
     SubscriptBox["Y", "lm"], "(", 
     RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], ")"}], 
    SuperscriptBox["e", 
     RowBox[{
      RowBox[{"-", "i"}], " ", "\[Omega]", " ", "t"}]]}], TraditionalForm]]],
 ").\n\n",
 StyleBox["On the stealth black hole, the linearized Einstein equation is \
therefore modified only by an effective SET that has only a nonzero \
rr-component. We derive the Regge-Wheeler and Zerilli equations corresponding \
to this in the notebook master_equations_stealth_BH_RW_gauge.nb.",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.815456899705196*^9, 3.815456970295804*^9}, {
   3.8154570300753975`*^9, 3.815457160223298*^9}, {3.8154572137545185`*^9, 
   3.8154573084045134`*^9}, 3.815458161657016*^9, {3.815477091011133*^9, 
   3.815477092218537*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowSize->{874, 787},
WindowMargins->{{922, Automatic}, {Automatic, 119}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "ReverseColor.nb"]]}, Visible -> False, 
  FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (September 21, 2016)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 178, 6, 70, "Section"],
Cell[761, 30, 2074, 51, 87, "Text"],
Cell[CellGroupData[{
Cell[2860, 85, 151, 2, 49, "Subsection"],
Cell[3014, 89, 586, 16, 67, "Text"],
Cell[CellGroupData[{
Cell[3625, 109, 3500, 95, 520, "Input"],
Cell[CellGroupData[{
Cell[7150, 208, 892, 12, 22, "Print"],
Cell[8045, 222, 1161, 19, 22, "Print"],
Cell[9209, 243, 911, 12, 41, "Print"],
Cell[10123, 257, 870, 11, 22, "Print"],
Cell[10996, 270, 853, 11, 22, "Print"],
Cell[11852, 283, 890, 12, 22, "Print"],
Cell[12745, 297, 1168, 20, 22, "Print"],
Cell[13916, 319, 911, 12, 41, "Print"],
Cell[14830, 333, 892, 12, 22, "Print"],
Cell[15725, 347, 1159, 19, 22, "Print"],
Cell[16887, 368, 961, 13, 41, "Print"],
Cell[17851, 383, 889, 12, 22, "Print"],
Cell[18743, 397, 1047, 14, 77, "Print"],
Cell[19793, 413, 890, 12, 22, "Print"],
Cell[20686, 427, 1134, 19, 22, "Print"],
Cell[21823, 448, 1216, 20, 22, "Print"],
Cell[23042, 470, 1317, 20, 41, "Print"],
Cell[24362, 492, 1275, 20, 22, "Print"],
Cell[25640, 514, 1295, 20, 22, "Print"],
Cell[26938, 536, 1226, 20, 22, "Print"],
Cell[28167, 558, 1236, 20, 22, "Print"],
Cell[29406, 580, 1384, 25, 22, "Print"],
Cell[30793, 607, 1486, 27, 22, "Print"],
Cell[32282, 636, 1461, 26, 22, "Print"],
Cell[33746, 664, 1479, 26, 22, "Print"],
Cell[35228, 692, 1305, 22, 22, "Print"],
Cell[36536, 716, 1432, 26, 22, "Print"],
Cell[37971, 744, 1450, 27, 41, "Print"],
Cell[39424, 773, 1474, 27, 22, "Print"],
Cell[40901, 802, 1394, 25, 22, "Print"],
Cell[42298, 829, 899, 12, 22, "Print"],
Cell[43200, 843, 1275, 20, 22, "Print"],
Cell[44478, 865, 905, 12, 22, "Print"],
Cell[45386, 879, 1404, 25, 22, "Print"],
Cell[46793, 906, 1461, 26, 22, "Print"],
Cell[48257, 934, 1402, 25, 22, "Print"],
Cell[49662, 961, 1290, 21, 22, "Print"],
Cell[50955, 984, 1036, 16, 22, "Print"],
Cell[51994, 1002, 1026, 16, 22, "Print"],
Cell[53023, 1020, 1038, 16, 22, "Print"],
Cell[54064, 1038, 1292, 21, 22, "Print"],
Cell[55359, 1061, 1247, 20, 22, "Print"],
Cell[56609, 1083, 1248, 20, 22, "Print"],
Cell[57860, 1105, 1266, 21, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[59153, 1130, 591, 14, 67, "Text"],
Cell[59747, 1146, 17971, 436, 2197, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[77755, 1587, 323, 10, 41, "Subsection"],
Cell[78081, 1599, 386, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[78492, 1612, 1134, 30, 121, "Input"],
Cell[79629, 1644, 2126, 57, 53, "Output"]
}, Open  ]],
Cell[81770, 1704, 272, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[82067, 1711, 1403, 42, 158, "Input"],
Cell[CellGroupData[{
Cell[83495, 1757, 1015, 19, 22, "Print"],
Cell[84513, 1778, 926, 17, 22, "Print"],
Cell[85442, 1797, 1116, 21, 22, "Print"]
}, Open  ]],
Cell[86573, 1821, 6428, 187, 58, "Output"]
}, Open  ]],
Cell[93016, 2011, 234, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[93275, 2018, 685, 18, 82, "Input"],
Cell[93963, 2038, 3789, 115, 53, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[97801, 2159, 193, 2, 41, "Subsection"],
Cell[97997, 2163, 1125, 33, 93, "Text"],
Cell[CellGroupData[{
Cell[99147, 2200, 1060, 28, 126, "Input"],
Cell[CellGroupData[{
Cell[100232, 2232, 1233, 22, 22, "Print"],
Cell[101468, 2256, 1411, 26, 22, "Print"],
Cell[102882, 2284, 1309, 23, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[104240, 2313, 111, 1, 39, "Subsubsection"],
Cell[104354, 2316, 611, 17, 48, "Text"],
Cell[CellGroupData[{
Cell[104990, 2337, 2632, 81, 219, "Input"],
Cell[CellGroupData[{
Cell[107647, 2422, 605, 11, 22, "Print"],
Cell[108255, 2435, 703, 14, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[108985, 2453, 411, 9, 67, "Text"],
Cell[CellGroupData[{
Cell[109421, 2466, 2203, 71, 155, "Input"],
Cell[CellGroupData[{
Cell[111649, 2541, 569, 11, 22, "Print"],
Cell[112221, 2554, 573, 11, 22, "Print"],
Cell[112797, 2567, 579, 12, 22, "Print"],
Cell[113379, 2581, 581, 12, 22, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[114021, 2600, 352, 11, 33, "Subsubsection"],
Cell[114376, 2613, 133, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[114534, 2618, 1139, 28, 138, "Input"],
Cell[115676, 2648, 39534, 1094, 216, "Output"]
}, Open  ]],
Cell[155225, 3745, 156, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[155406, 3752, 944, 22, 121, "Input"],
Cell[156353, 3776, 29608, 858, 180, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[186010, 4640, 362, 6, 33, "Subsubsection"],
Cell[186375, 4648, 924, 25, 105, "Text"],
Cell[CellGroupData[{
Cell[187324, 4677, 410, 12, 66, "Input"],
Cell[187737, 4691, 660, 13, 22, "Print"]
}, Open  ]],
Cell[188412, 4707, 491, 12, 49, "Text"],
Cell[CellGroupData[{
Cell[188928, 4723, 1345, 38, 141, "Input"],
Cell[190276, 4763, 2206, 71, 56, "Output"]
}, Open  ]],
Cell[192497, 4837, 202, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[192724, 4845, 897, 24, 140, "Input"],
Cell[193624, 4871, 26600, 726, 179, "Output"],
Cell[220227, 5599, 17698, 520, 152, "Output"]
}, Open  ]],
Cell[237940, 6122, 1593, 41, 162, "Text"],
Cell[CellGroupData[{
Cell[239558, 6167, 3630, 102, 373, "Input"],
Cell[CellGroupData[{
Cell[243213, 6273, 656, 14, 22, "Print"],
Cell[243872, 6289, 640, 14, 22, "Print"]
}, Open  ]],
Cell[244527, 6306, 10784, 311, 98, "Output"]
}, Open  ]],
Cell[255326, 6620, 185, 2, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[255548, 6627, 199, 5, 33, "Subsubsection"],
Cell[255750, 6634, 282, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[256057, 6646, 73, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[256155, 6652, 447, 6, 22, "Print"],
Cell[256605, 6660, 718, 13, 22, "Print"],
Cell[257326, 6675, 488, 6, 22, "Print"],
Cell[257817, 6683, 449, 6, 22, "Print"],
Cell[258269, 6691, 602, 8, 59, "Print"],
Cell[258874, 6701, 447, 6, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[259348, 6711, 494, 18, 32, "Text"],
Cell[CellGroupData[{
Cell[259867, 6733, 3706, 104, 384, "Input"],
Cell[CellGroupData[{
Cell[263598, 6841, 793, 15, 22, "Print"],
Cell[264394, 6858, 849, 16, 22, "Print"],
Cell[265246, 6876, 849, 16, 22, "Print"],
Cell[266098, 6894, 861, 16, 22, "Print"],
Cell[266962, 6912, 867, 16, 22, "Print"],
Cell[267832, 6930, 803, 15, 22, "Print"],
Cell[268638, 6947, 823, 15, 22, "Print"],
Cell[269464, 6964, 972, 20, 24, "Print"],
Cell[270439, 6986, 979, 20, 24, "Print"],
Cell[271421, 7008, 835, 16, 22, "Print"],
Cell[272259, 7026, 893, 17, 22, "Print"],
Cell[273155, 7045, 1019, 21, 22, "Print"],
Cell[274177, 7068, 1037, 22, 22, "Print"],
Cell[275217, 7092, 1065, 22, 22, "Print"],
Cell[276285, 7116, 981, 20, 22, "Print"],
Cell[277269, 7138, 989, 19, 22, "Print"],
Cell[278261, 7159, 1083, 23, 22, "Print"],
Cell[279347, 7184, 833, 15, 22, "Print"],
Cell[280183, 7201, 832, 15, 22, "Print"],
Cell[281018, 7218, 837, 15, 22, "Print"],
Cell[281858, 7235, 2329, 61, 29, "Print"],
Cell[284190, 7298, 1937, 46, 29, "Print"],
Cell[286130, 7346, 1937, 46, 29, "Print"],
Cell[288070, 7394, 1937, 46, 29, "Print"],
Cell[290010, 7442, 3162, 79, 29, "Print"],
Cell[293175, 7523, 2334, 61, 41, "Print"],
Cell[295512, 7586, 1935, 46, 29, "Print"],
Cell[297450, 7634, 1937, 46, 29, "Print"],
Cell[299390, 7682, 3159, 79, 29, "Print"],
Cell[302552, 7763, 3160, 79, 29, "Print"],
Cell[305715, 7844, 2130, 54, 29, "Print"],
Cell[307848, 7900, 1937, 46, 29, "Print"],
Cell[309788, 7948, 3162, 79, 29, "Print"],
Cell[312953, 8029, 3160, 79, 29, "Print"],
Cell[316116, 8110, 3159, 79, 29, "Print"],
Cell[319278, 8191, 2575, 69, 29, "Print"],
Cell[321856, 8262, 881, 16, 22, "Print"],
Cell[322740, 8280, 986, 19, 22, "Print"],
Cell[323729, 8301, 849, 16, 22, "Print"],
Cell[324581, 8319, 1289, 34, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[325897, 8357, 324, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[326246, 8367, 10080, 282, 726, "Input"],
Cell[CellGroupData[{
Cell[336351, 8653, 755, 14, 22, "Print"],
Cell[337109, 8669, 733, 13, 22, "Print"],
Cell[337845, 8684, 753, 14, 22, "Print"],
Cell[338601, 8700, 735, 13, 22, "Print"],
Cell[339339, 8715, 735, 13, 22, "Print"],
Cell[340077, 8730, 735, 13, 22, "Print"],
Cell[340815, 8745, 735, 13, 22, "Print"],
Cell[341553, 8760, 737, 13, 22, "Print"],
Cell[342293, 8775, 735, 13, 22, "Print"],
Cell[343031, 8790, 734, 13, 22, "Print"],
Cell[343768, 8805, 749, 14, 22, "Print"],
Cell[344520, 8821, 4200, 124, 29, "Print"],
Cell[348723, 8947, 3819, 110, 29, "Print"],
Cell[352545, 9059, 4594, 137, 29, "Print"],
Cell[357142, 9198, 4476, 132, 29, "Print"],
Cell[361621, 9332, 3130, 77, 29, "Print"],
Cell[364754, 9411, 4279, 125, 44, "Print"],
Cell[369036, 9538, 4595, 137, 29, "Print"],
Cell[373634, 9677, 4474, 132, 29, "Print"],
Cell[378111, 9811, 3132, 77, 29, "Print"],
Cell[381246, 9890, 3132, 77, 29, "Print"],
Cell[384381, 9969, 4003, 117, 29, "Print"],
Cell[388387, 10088, 1884, 45, 29, "Print"],
Cell[390274, 10135, 3132, 77, 29, "Print"],
Cell[393409, 10214, 3132, 77, 29, "Print"],
Cell[396544, 10293, 3134, 77, 29, "Print"],
Cell[399681, 10372, 4426, 131, 29, "Print"],
Cell[404110, 10505, 12501, 313, 29, "Print"],
Cell[416614, 10820, 12499, 313, 29, "Print"],
Cell[429116, 11135, 12499, 313, 29, "Print"],
Cell[441618, 11450, 12499, 313, 29, "Print"],
Cell[454120, 11765, 3130, 77, 29, "Print"],
Cell[457253, 11844, 12499, 313, 29, "Print"],
Cell[469755, 12159, 12499, 313, 29, "Print"],
Cell[482257, 12474, 12499, 313, 29, "Print"],
Cell[494759, 12789, 12499, 313, 29, "Print"],
Cell[507261, 13104, 3130, 77, 29, "Print"],
Cell[510394, 13183, 12499, 313, 29, "Print"],
Cell[522896, 13498, 3130, 77, 29, "Print"],
Cell[526029, 13577, 12501, 313, 29, "Print"],
Cell[538533, 13892, 12501, 313, 29, "Print"],
Cell[551037, 14207, 12501, 313, 29, "Print"],
Cell[563541, 14522, 3130, 77, 29, "Print"],
Cell[566674, 14601, 12501, 313, 29, "Print"],
Cell[579178, 14916, 3128, 77, 29, "Print"],
Cell[582309, 14995, 12498, 313, 29, "Print"],
Cell[594810, 15310, 3130, 77, 29, "Print"],
Cell[597943, 15389, 12501, 313, 29, "Print"],
Cell[610447, 15704, 12499, 313, 29, "Print"],
Cell[622949, 16019, 3128, 77, 29, "Print"],
Cell[626080, 16098, 3130, 77, 29, "Print"],
Cell[629213, 16177, 3128, 77, 29, "Print"],
Cell[632344, 16256, 3128, 77, 29, "Print"],
Cell[635475, 16335, 3130, 77, 29, "Print"],
Cell[638608, 16414, 3130, 77, 29, "Print"],
Cell[641741, 16493, 3130, 77, 29, "Print"],
Cell[644874, 16572, 3130, 77, 29, "Print"],
Cell[648007, 16651, 3128, 77, 29, "Print"],
Cell[651138, 16730, 3130, 77, 29, "Print"],
Cell[654271, 16809, 4644, 116, 29, "Print"],
Cell[658918, 16927, 745, 14, 22, "Print"],
Cell[659666, 16943, 2747, 82, 24, "Print"]
}, Open  ]]
}, Open  ]],
Cell[662440, 17029, 234, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[662699, 17036, 561, 15, 88, "Input"],
Cell[663263, 17053, 20734, 620, 118, "Output"]
}, Open  ]],
Cell[684012, 17676, 165, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[684202, 17682, 2370, 69, 211, "Input"],
Cell[686575, 17753, 3055, 98, 49, "Output"]
}, Open  ]],
Cell[689645, 17854, 433, 10, 49, "Text"],
Cell[CellGroupData[{
Cell[690103, 17868, 1276, 35, 107, "Input"],
Cell[691382, 17905, 553, 11, 22, "Print"],
Cell[691938, 17918, 4009, 132, 52, "Output"]
}, Open  ]],
Cell[695962, 18053, 755, 20, 49, "Text"],
Cell[CellGroupData[{
Cell[696742, 18077, 855, 26, 88, "Input"],
Cell[697600, 18105, 345, 7, 21, "Message"],
Cell[697948, 18114, 1626, 50, 51, "Output"]
}, Open  ]],
Cell[699589, 18167, 614, 13, 87, "Text"],
Cell[CellGroupData[{
Cell[700228, 18184, 307, 8, 50, "Input"],
Cell[700538, 18194, 10765, 311, 60, "Output"]
}, Open  ]],
Cell[711318, 18508, 214, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[711557, 18515, 426, 10, 69, "Input"],
Cell[711986, 18527, 3807, 122, 45, "Output"]
}, Open  ]],
Cell[715808, 18652, 131, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[715964, 18657, 1160, 31, 126, "Input"],
Cell[717127, 18690, 2871, 80, 96, "Output"]
}, Open  ]],
Cell[720013, 18773, 1134, 26, 129, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

